(FAMILY t1-stixgeral-italic)
(CODINGSCHEME STIXT1)
(DESIGNSIZE R 10.0)
(DESIGNUNITS R 1000)
(COMMENT DESIGNSIZE (1 em) IS IN POINTS)
(COMMENT OTHER DIMENSIONS ARE MULTIPLES OF DESIGNSIZE/1000)
(BOUNDARYCHAR O 27)
(FONTDIMEN
   (SLANT R 0.292989)
   (SPACE D 250)
   (STRETCH D 125)
   (SHRINK D 83)
   (XHEIGHT D 428)
   (QUAD D 1000)
   (EXTRASPACE D 83)
   )
(LIGTABLE
   (LABEL O 17) (comment guilsinglright)
   (KRN O 230 R -64) (comment Ydieresis)
   (KRN O 335 R -64) (comment Yacute)
   (KRN O 303 R -10) (comment Atilde)
   (KRN O 300 R -10) (comment Agrave)
   (KRN O 302 R -10) (comment Acircumflex)
   (KRN C A R -10)
   (KRN C T R -59)
   (KRN C V R -59)
   (KRN C W R -52)
   (KRN C Y R -64)
   (KRN O 301 R -10) (comment Aacute)
   (KRN O 304 R -10) (comment Adieresis)
   (KRN O 305 R -10) (comment Aring)
   (KRN O 306 R -36) (comment AE)
   (STOP)
   (LABEL O 20) (comment quotedblleft)
   (KRN O 230 R -21) (comment Ydieresis)
   (KRN O 335 R -21) (comment Yacute)
   (KRN O 303 R -73) (comment Atilde)
   (KRN O 300 R -73) (comment Agrave)
   (KRN O 302 R -73) (comment Acircumflex)
   (KRN C A R -73)
   (KRN C T R -5)
   (KRN C V R -7)
   (KRN C W R -5)
   (KRN C Y R -21)
   (KRN O 301 R -73) (comment Aacute)
   (KRN O 304 R -73) (comment Adieresis)
   (KRN O 305 R -73) (comment Aring)
   (KRN O 306 R -121) (comment AE)
   (STOP)
   (LABEL O 21) (comment quotedblright)
   (KRN O 230 R -25) (comment Ydieresis)
   (KRN O 335 R -25) (comment Yacute)
   (KRN O 303 R -75) (comment Atilde)
   (KRN O 300 R -75) (comment Agrave)
   (KRN O 302 R -75) (comment Acircumflex)
   (KRN C A R -75)
   (KRN C T R -9)
   (KRN C V R -12)
   (KRN C W R -9)
   (KRN C Y R -25)
   (KRN O 301 R -75) (comment Aacute)
   (KRN O 304 R -75) (comment Adieresis)
   (KRN O 305 R -75) (comment Aring)
   (KRN O 306 R -129) (comment AE)
   (STOP)
   (LABEL O 22) (comment quotedblbase)
   (KRN O 230 R -55) (comment Ydieresis)
   (KRN O 335 R -55) (comment Yacute)
   (KRN O 303 R 9) (comment Atilde)
   (KRN C A R 9)
   (KRN C T R -52)
   (KRN C V R -80)
   (KRN C W R -67)
   (KRN C Y R -55)
   (KRN O 300 R 9) (comment Agrave)
   (KRN O 301 R 9) (comment Aacute)
   (KRN O 302 R 9) (comment Acircumflex)
   (KRN O 304 R 9) (comment Adieresis)
   (KRN O 305 R 9) (comment Aring)
   (KRN O 306 R -2) (comment AE)
   (STOP)
   (LABEL O 24) (comment guillemotright)
   (KRN O 230 R -65) (comment Ydieresis)
   (KRN O 335 R -65) (comment Yacute)
   (KRN O 303 R -11) (comment Atilde)
   (KRN O 300 R -11) (comment Agrave)
   (KRN O 302 R -11) (comment Acircumflex)
   (KRN C A R -11)
   (KRN C T R -60)
   (KRN C V R -60)
   (KRN C W R -53)
   (KRN C Y R -65)
   (KRN O 301 R -11) (comment Aacute)
   (KRN O 304 R -11) (comment Adieresis)
   (KRN O 305 R -11) (comment Aring)
   (KRN O 306 R -37) (comment AE)
   (STOP)
   (LABEL O 25) (comment endash)
   (LIG O 55 O 26)
   (STOP)
   (LABEL O 33) (comment ff)
   (LIG C l O 37)
   (LIG C i O 36)
   (STOP)
   (LABEL O 41) (comment exclam)
   (LIG O 140 O 275)
   (STOP)
   (LABEL O 47) (comment quoteright)
   (LIG O 47 O 21)
   (KRN O 270 R -23) (comment ydieresis)
   (KRN O 375 R -23) (comment yacute)
   (KRN O 262 R -51) (comment scaron)
   (KRN O 365 R -65) (comment otilde)
   (KRN O 370 R -65) (comment oslash)
   (KRN O 362 R -65) (comment ograve)
   (KRN O 366 R -65) (comment odieresis)
   (KRN O 364 R -65) (comment ocircumflex)
   (KRN O 363 R -65) (comment oacute)
   (KRN O 303 R -68) (comment Atilde)
   (KRN O 54 R -63) (comment comma)
   (KRN O 56 R -69) (comment period)
   (KRN C A R -68)
   (KRN C d R -64)
   (KRN C o R -65)
   (KRN C r R -45)
   (KRN C s R -51)
   (KRN C t R -34)
   (KRN C v R -25)
   (KRN C w R -19)
   (KRN C y R -23)
   (KRN O 300 R -68) (comment Agrave)
   (KRN O 301 R -68) (comment Aacute)
   (KRN O 302 R -68) (comment Acircumflex)
   (KRN O 304 R -68) (comment Adieresis)
   (KRN O 305 R -68) (comment Aring)
   (KRN O 306 R -122) (comment AE)
   (STOP)
   (LABEL O 54) (comment comma)
   (KRN C 1 R -30)
   (KRN O 47 R -37) (comment quoteright)
   (KRN O 21 R -37) (comment quotedblright)
   (STOP)
   (LABEL O 55) (comment hyphen)
   (LIG O 55 O 25)
   (KRN O 230 R -40) (comment Ydieresis)
   (KRN O 335 R -40) (comment Yacute)
   (KRN O 303 R 14) (comment Atilde)
   (KRN O 300 R 14) (comment Agrave)
   (KRN O 302 R 14) (comment Acircumflex)
   (KRN C A R 14)
   (KRN C T R -34)
   (KRN C V R -28)
   (KRN C W R -22)
   (KRN C Y R -40)
   (KRN O 301 R 14) (comment Aacute)
   (KRN O 304 R 14) (comment Adieresis)
   (KRN O 305 R 14) (comment Aring)
   (KRN O 306 R -9) (comment AE)
   (STOP)
   (LABEL O 56) (comment period)
   (KRN O 47 R -35) (comment quoteright)
   (KRN O 21 R -35) (comment quotedblright)
   (STOP)
   (LABEL O 74) (comment less)
   (LIG O 74 O 23)
   (STOP)
   (LABEL O 76) (comment greater)
   (LIG O 76 O 24)
   (STOP)
   (LABEL O 77) (comment question)
   (LIG O 140 O 276)
   (STOP)
   (LABEL C A)
   (KRN O 270 R -54) (comment ydieresis)
   (KRN O 230 R -20) (comment Ydieresis)
   (KRN O 375 R -54) (comment yacute)
   (KRN O 335 R -20) (comment Yacute)
   (KRN O 365 R -16) (comment otilde)
   (KRN O 325 R -37) (comment Otilde)
   (KRN O 370 R -16) (comment oslash)
   (KRN O 330 R -37) (comment Oslash)
   (KRN O 362 R -16) (comment ograve)
   (KRN O 322 R -37) (comment Ograve)
   (KRN O 364 R -16) (comment ocircumflex)
   (KRN O 324 R -37) (comment Ocircumflex)
   (KRN O 363 R -16) (comment oacute)
   (KRN O 323 R -37) (comment Oacute)
   (KRN O 350 R -18) (comment egrave)
   (KRN O 353 R -18) (comment edieresis)
   (KRN O 352 R -18) (comment ecircumflex)
   (KRN O 351 R -18) (comment eacute)
   (KRN O 343 R -5) (comment atilde)
   (KRN O 345 R -5) (comment aring)
   (KRN O 340 R -5) (comment agrave)
   (KRN O 344 R -5) (comment adieresis)
   (KRN O 342 R -5) (comment acircumflex)
   (KRN O 341 R -5) (comment aacute)
   (KRN O 54 R 19) (comment comma)
   (KRN O 56 R 19) (comment period)
   (KRN C C R -36)
   (KRN C G R -29)
   (KRN C O R -37)
   (KRN C Q R -36)
   (KRN C T R -14)
   (KRN C U R -46)
   (KRN C V R -65)
   (KRN C W R -59)
   (KRN C Y R -20)
   (KRN C a R -5)
   (KRN C c R -17)
   (KRN C d R -4)
   (KRN C e R -18)
   (KRN C g R -31)
   (KRN C o R -16)
   (KRN C q R -11)
   (KRN C t R -7)
   (KRN C u R -9)
   (KRN C v R -35)
   (KRN C w R -32)
   (KRN C y R -54)
   (KRN O 23 R -29) (comment guillemotleft)
   (KRN O 307 R -36) (comment Ccedilla)
   (KRN O 326 R -37) (comment Odieresis)
   (KRN O 331 R -46) (comment Ugrave)
   (KRN O 332 R -46) (comment Uacute)
   (KRN O 333 R -46) (comment Ucircumflex)
   (KRN O 334 R -46) (comment Udieresis)
   (KRN O 347 R -19) (comment ccedilla)
   (KRN O 366 R -16) (comment odieresis)
   (KRN O 371 R -9) (comment ugrave)
   (KRN O 372 R -9) (comment uacute)
   (KRN O 373 R -9) (comment ucircumflex)
   (KRN O 374 R -9) (comment udieresis)
   (KRN O 47 R -77) (comment quoteright)
   (KRN O 21 R -77) (comment quotedblright)
   (KRN O 16 R -28) (comment guilsinglleft)
   (STOP)
   (LABEL C B)
   (KRN O 230 R -34) (comment Ydieresis)
   (KRN O 335 R -34) (comment Yacute)
   (KRN O 300 R -20) (comment Agrave)
   (KRN C A R -20)
   (KRN C V R -25)
   (KRN C W R -19)
   (KRN C Y R -34)
   (KRN O 301 R -20) (comment Aacute)
   (KRN O 302 R -20) (comment Acircumflex)
   (KRN O 303 R -20) (comment Atilde)
   (KRN O 304 R -20) (comment Adieresis)
   (KRN O 305 R -20) (comment Aring)
   (KRN O 306 R -32) (comment AE)
   (KRN O 327 R 8) (comment OE)
   (STOP)
   (LABEL C C)
   (KRN O 325 R -7) (comment Otilde)
   (KRN O 330 R -7) (comment Oslash)
   (KRN O 324 R -7) (comment Ocircumflex)
   (KRN O 303 R -19) (comment Atilde)
   (KRN O 302 R -19) (comment Acircumflex)
   (KRN C A R -19)
   (KRN C H R -5)
   (KRN C K R -17)
   (KRN C O R -7)
   (KRN O 300 R -19) (comment Agrave)
   (KRN O 301 R -19) (comment Aacute)
   (KRN O 304 R -19) (comment Adieresis)
   (KRN O 305 R -19) (comment Aring)
   (KRN O 306 R -31) (comment AE)
   (KRN O 322 R -7) (comment Ograve)
   (KRN O 323 R -7) (comment Oacute)
   (KRN O 326 R -7) (comment Odieresis)
   (STOP)
   (LABEL C D)
   (KRN O 230 R -37) (comment Ydieresis)
   (KRN O 335 R -37) (comment Yacute)
   (KRN C A R -20)
   (KRN C J R -27)
   (KRN C T R -9)
   (KRN C V R -28)
   (KRN C W R -22)
   (KRN C X R -26)
   (KRN C Y R -37)
   (KRN O 300 R -20) (comment Agrave)
   (KRN O 301 R -20) (comment Aacute)
   (KRN O 302 R -20) (comment Acircumflex)
   (KRN O 303 R -20) (comment Atilde)
   (KRN O 304 R -20) (comment Adieresis)
   (KRN O 305 R -20) (comment Aring)
   (STOP)
   (LABEL C F)
   (KRN O 371 R -43) (comment ugrave)
   (KRN O 374 R -43) (comment udieresis)
   (KRN O 373 R -43) (comment ucircumflex)
   (KRN O 372 R -43) (comment uacute)
   (KRN O 365 R -65) (comment otilde)
   (KRN O 325 R -32) (comment Otilde)
   (KRN O 330 R -32) (comment Oslash)
   (KRN O 362 R -65) (comment ograve)
   (KRN O 364 R -65) (comment ocircumflex)
   (KRN O 324 R -32) (comment Ocircumflex)
   (KRN O 354 R -35) (comment igrave)
   (KRN O 357 R -35) (comment idieresis)
   (KRN O 356 R -35) (comment icircumflex)
   (KRN O 355 R -35) (comment iacute)
   (KRN O 350 R -67) (comment egrave)
   (KRN O 353 R -67) (comment edieresis)
   (KRN O 352 R -67) (comment ecircumflex)
   (KRN O 340 R -60) (comment agrave)
   (KRN O 54 R -77) (comment comma)
   (KRN O 55 R -32) (comment hyphen)
   (KRN O 56 R -80) (comment period)
   (KRN C A R -54)
   (KRN C J R -59)
   (KRN C O R -32)
   (KRN C a R -60)
   (KRN C e R -67)
   (KRN C i R -35)
   (KRN C j R -38)
   (KRN C o R -65)
   (KRN C r R -45)
   (KRN C u R -43)
   (KRN O 300 R -54) (comment Agrave)
   (KRN O 301 R -54) (comment Aacute)
   (KRN O 302 R -54) (comment Acircumflex)
   (KRN O 303 R -54) (comment Atilde)
   (KRN O 304 R -54) (comment Adieresis)
   (KRN O 305 R -54) (comment Aring)
   (KRN O 322 R -32) (comment Ograve)
   (KRN O 323 R -32) (comment Oacute)
   (KRN O 326 R -32) (comment Odieresis)
   (KRN O 341 R -60) (comment aacute)
   (KRN O 342 R -60) (comment acircumflex)
   (KRN O 343 R -57) (comment atilde)
   (KRN O 344 R -58) (comment adieresis)
   (KRN O 345 R -60) (comment aring)
   (KRN O 346 R -69) (comment ae)
   (KRN O 351 R -67) (comment eacute)
   (KRN O 363 R -65) (comment oacute)
   (KRN O 366 R -44) (comment odieresis)
   (KRN O 370 R -66) (comment oslash)
   (KRN O 367 R -62) (comment oe)
   (STOP)
   (LABEL C G)
   (KRN O 230 R -13) (comment Ydieresis)
   (KRN O 335 R -13) (comment Yacute)
   (KRN C A R -15)
   (KRN C T R -14)
   (KRN C V R -5)
   (KRN C W R -3)
   (KRN C Y R -13)
   (KRN O 300 R -15) (comment Agrave)
   (KRN O 301 R -15) (comment Aacute)
   (KRN O 302 R -15) (comment Acircumflex)
   (KRN O 303 R -15) (comment Atilde)
   (KRN O 304 R -15) (comment Adieresis)
   (KRN O 305 R -15) (comment Aring)
   (KRN O 306 R -29) (comment AE)
   (STOP)
   (LABEL C J)
   (KRN O 303 R -20) (comment Atilde)
   (KRN O 300 R -20) (comment Agrave)
   (KRN O 302 R -20) (comment Acircumflex)
   (KRN O 301 R -20) (comment Aacute)
   (KRN C A R -20)
   (KRN O 304 R -20) (comment Adieresis)
   (KRN O 305 R -20) (comment Aring)
   (KRN O 306 R -54) (comment AE)
   (STOP)
   (LABEL C K)
   (KRN O 270 R -63) (comment ydieresis)
   (KRN O 375 R -63) (comment yacute)
   (KRN O 371 R -9) (comment ugrave)
   (KRN O 373 R -9) (comment ucircumflex)
   (KRN O 372 R -9) (comment uacute)
   (KRN O 222 R 6) (comment Scaron)
   (KRN O 365 R -16) (comment otilde)
   (KRN O 325 R -44) (comment Otilde)
   (KRN O 370 R -16) (comment oslash)
   (KRN O 330 R -44) (comment Oslash)
   (KRN O 362 R -16) (comment ograve)
   (KRN O 322 R -44) (comment Ograve)
   (KRN O 364 R -16) (comment ocircumflex)
   (KRN O 324 R -44) (comment Ocircumflex)
   (KRN O 350 R -18) (comment egrave)
   (KRN O 353 R -18) (comment edieresis)
   (KRN O 352 R -18) (comment ecircumflex)
   (KRN O 351 R -18) (comment eacute)
   (KRN O 307 R -45) (comment Ccedilla)
   (KRN O 343 R -5) (comment atilde)
   (KRN O 340 R -5) (comment agrave)
   (KRN O 342 R -5) (comment acircumflex)
   (KRN O 341 R -5) (comment aacute)
   (KRN O 55 R -42) (comment hyphen)
   (KRN C C R -45)
   (KRN C G R -38)
   (KRN C O R -44)
   (KRN C S R 6)
   (KRN C T R 19)
   (KRN C a R -5)
   (KRN C e R -18)
   (KRN C o R -16)
   (KRN C u R -9)
   (KRN C y R -63)
   (KRN O 323 R -44) (comment Oacute)
   (KRN O 326 R -44) (comment Odieresis)
   (KRN O 344 R -5) (comment adieresis)
   (KRN O 345 R -5) (comment aring)
   (KRN O 346 R -5) (comment ae)
   (KRN O 363 R -16) (comment oacute)
   (KRN O 366 R -16) (comment odieresis)
   (KRN O 374 R -9) (comment udieresis)
   (KRN O 327 R -42) (comment OE)
   (STOP)
   (LABEL C L)
   (KRN O 270 R -15) (comment ydieresis)
   (KRN O 230 R -21) (comment Ydieresis)
   (KRN O 375 R -15) (comment yacute)
   (KRN O 335 R -21) (comment Yacute)
   (KRN O 371 R 22) (comment ugrave)
   (KRN O 331 R -9) (comment Ugrave)
   (KRN O 373 R 22) (comment ucircumflex)
   (KRN O 333 R -9) (comment Ucircumflex)
   (KRN O 372 R 22) (comment uacute)
   (KRN O 332 R -9) (comment Uacute)
   (KRN O 222 R 18) (comment Scaron)
   (KRN O 330 R 10) (comment Oslash)
   (KRN O 303 R 41) (comment Atilde)
   (KRN O 300 R 41) (comment Agrave)
   (KRN O 302 R 41) (comment Acircumflex)
   (KRN O 55 R 56) (comment hyphen)
   (KRN C A R 41)
   (KRN C C R 5)
   (KRN C G R 11)
   (KRN C O R 10)
   (KRN C S R 18)
   (KRN C T R -15)
   (KRN C U R -9)
   (KRN C V R -41)
   (KRN C W R -34)
   (KRN C Y R -21)
   (KRN C u R 22)
   (KRN C y R -15)
   (KRN O 301 R 41) (comment Aacute)
   (KRN O 304 R 41) (comment Adieresis)
   (KRN O 305 R 41) (comment Aring)
   (KRN O 306 R 29) (comment AE)
   (KRN O 307 R 5) (comment Ccedilla)
   (KRN O 322 R 10) (comment Ograve)
   (KRN O 323 R 10) (comment Oacute)
   (KRN O 324 R 10) (comment Ocircumflex)
   (KRN O 325 R 10) (comment Otilde)
   (KRN O 326 R 10) (comment Odieresis)
   (KRN O 334 R -9) (comment Udieresis)
   (KRN O 374 R 20) (comment udieresis)
   (KRN O 47 R -78) (comment quoteright)
   (KRN O 21 R -78) (comment quotedblright)
   (STOP)
   (LABEL C N)
   (KRN O 371 R -11) (comment ugrave)
   (KRN O 373 R -11) (comment ucircumflex)
   (KRN O 372 R -11) (comment uacute)
   (KRN O 365 R -12) (comment otilde)
   (KRN O 325 R -2) (comment Otilde)
   (KRN O 330 R -2) (comment Oslash)
   (KRN O 362 R -12) (comment ograve)
   (KRN O 322 R -2) (comment Ograve)
   (KRN O 364 R -12) (comment ocircumflex)
   (KRN O 324 R -2) (comment Ocircumflex)
   (KRN O 350 R -14) (comment egrave)
   (KRN O 353 R -14) (comment edieresis)
   (KRN O 352 R -14) (comment ecircumflex)
   (KRN O 343 R -8) (comment atilde)
   (KRN O 303 R -19) (comment Atilde)
   (KRN O 340 R -8) (comment agrave)
   (KRN O 300 R -19) (comment Agrave)
   (KRN O 342 R -8) (comment acircumflex)
   (KRN O 302 R -19) (comment Acircumflex)
   (KRN O 54 R 1) (comment comma)
   (KRN O 56 R -4) (comment period)
   (KRN C A R -19)
   (KRN C C R -5)
   (KRN C G R 1)
   (KRN C O R -2)
   (KRN C a R -8)
   (KRN C e R -14)
   (KRN C o R -12)
   (KRN C u R -11)
   (KRN O 301 R -19) (comment Aacute)
   (KRN O 304 R -19) (comment Adieresis)
   (KRN O 305 R -19) (comment Aring)
   (KRN O 306 R -31) (comment AE)
   (KRN O 307 R -5) (comment Ccedilla)
   (KRN O 323 R -2) (comment Oacute)
   (KRN O 326 R -2) (comment Odieresis)
   (KRN O 341 R -12) (comment aacute)
   (KRN O 344 R -12) (comment adieresis)
   (KRN O 345 R -12) (comment aring)
   (KRN O 346 R -11) (comment ae)
   (KRN O 351 R -14) (comment eacute)
   (KRN O 363 R -12) (comment oacute)
   (KRN O 366 R -12) (comment odieresis)
   (KRN O 370 R -13) (comment oslash)
   (KRN O 374 R -11) (comment udieresis)
   (STOP)
   (LABEL C O)
   (KRN O 230 R -34) (comment Ydieresis)
   (KRN O 335 R -34) (comment Yacute)
   (KRN O 303 R -16) (comment Atilde)
   (KRN O 300 R -16) (comment Agrave)
   (KRN O 302 R -16) (comment Acircumflex)
   (KRN C A R -16)
   (KRN C T R -5)
   (KRN C V R -29)
   (KRN C W R -23)
   (KRN C X R -26)
   (KRN C Y R -34)
   (KRN O 301 R -16) (comment Aacute)
   (KRN O 304 R -16) (comment Adieresis)
   (KRN O 305 R -16) (comment Aring)
   (KRN O 306 R -53) (comment AE)
   (STOP)
   (LABEL C P)
   (KRN O 365 R -54) (comment otilde)
   (KRN O 362 R -54) (comment ograve)
   (KRN O 364 R -54) (comment ocircumflex)
   (KRN O 350 R -61) (comment egrave)
   (KRN O 353 R -61) (comment edieresis)
   (KRN O 352 R -61) (comment ecircumflex)
   (KRN O 343 R -54) (comment atilde)
   (KRN O 303 R -62) (comment Atilde)
   (KRN O 300 R -62) (comment Agrave)
   (KRN O 342 R -54) (comment acircumflex)
   (KRN O 302 R -62) (comment Acircumflex)
   (KRN O 54 R -96) (comment comma)
   (KRN O 55 R -46) (comment hyphen)
   (KRN O 56 R -99) (comment period)
   (KRN C A R -62)
   (KRN C J R -72)
   (KRN C a R -54)
   (KRN C e R -61)
   (KRN C o R -54)
   (KRN O 301 R -62) (comment Aacute)
   (KRN O 304 R -62) (comment Adieresis)
   (KRN O 305 R -62) (comment Aring)
   (KRN O 306 R -98) (comment AE)
   (KRN O 340 R -54) (comment agrave)
   (KRN O 341 R -54) (comment aacute)
   (KRN O 344 R -54) (comment adieresis)
   (KRN O 345 R -54) (comment aring)
   (KRN O 346 R -67) (comment ae)
   (KRN O 351 R -66) (comment eacute)
   (KRN O 363 R -54) (comment oacute)
   (KRN O 366 R -45) (comment odieresis)
   (KRN O 370 R -44) (comment oslash)
   (KRN O 367 R -60) (comment oe)
   (STOP)
   (LABEL C R)
   (KRN O 270 R -1) (comment ydieresis)
   (KRN O 230 R -19) (comment Ydieresis)
   (KRN O 375 R -1) (comment yacute)
   (KRN O 335 R -19) (comment Yacute)
   (KRN O 371 R -7) (comment ugrave)
   (KRN O 331 R -23) (comment Ugrave)
   (KRN O 373 R -7) (comment ucircumflex)
   (KRN O 333 R -23) (comment Ucircumflex)
   (KRN O 332 R -23) (comment Uacute)
   (KRN O 365 R -14) (comment otilde)
   (KRN O 325 R -14) (comment Otilde)
   (KRN O 370 R -14) (comment oslash)
   (KRN O 330 R -14) (comment Oslash)
   (KRN O 362 R -14) (comment ograve)
   (KRN O 322 R -14) (comment Ograve)
   (KRN O 364 R -14) (comment ocircumflex)
   (KRN O 324 R -14) (comment Ocircumflex)
   (KRN O 350 R -16) (comment egrave)
   (KRN O 353 R -16) (comment edieresis)
   (KRN O 352 R -16) (comment ecircumflex)
   (KRN O 343 R -4) (comment atilde)
   (KRN O 340 R -4) (comment agrave)
   (KRN O 342 R -4) (comment acircumflex)
   (KRN O 55 R -16) (comment hyphen)
   (KRN C C R -13)
   (KRN C G R -6)
   (KRN C O R -14)
   (KRN C T R -1)
   (KRN C U R -23)
   (KRN C V R -36)
   (KRN C W R -30)
   (KRN C Y R -19)
   (KRN C a R -4)
   (KRN C e R -16)
   (KRN C o R -14)
   (KRN C u R -7)
   (KRN C y R -1)
   (KRN O 307 R -13) (comment Ccedilla)
   (KRN O 323 R -14) (comment Oacute)
   (KRN O 326 R -14) (comment Odieresis)
   (KRN O 334 R -23) (comment Udieresis)
   (KRN O 341 R -4) (comment aacute)
   (KRN O 344 R -4) (comment adieresis)
   (KRN O 345 R -4) (comment aring)
   (KRN O 346 R -3) (comment ae)
   (KRN O 351 R -16) (comment eacute)
   (KRN O 363 R -14) (comment oacute)
   (KRN O 366 R -14) (comment odieresis)
   (KRN O 372 R -7) (comment uacute)
   (KRN O 374 R -7) (comment udieresis)
   (KRN O 327 R -5) (comment OE)
   (KRN O 367 R -15) (comment oe)
   (STOP)
   (LABEL C S)
   (KRN O 230 R -2) (comment Ydieresis)
   (KRN O 335 R -2) (comment Yacute)
   (KRN O 303 R -3) (comment Atilde)
   (KRN O 300 R -3) (comment Agrave)
   (KRN O 302 R -3) (comment Acircumflex)
   (KRN C A R -3)
   (KRN C V R 4)
   (KRN C W R 7)
   (KRN C Y R -2)
   (KRN C t R -1)
   (KRN O 301 R -3) (comment Aacute)
   (KRN O 304 R -3) (comment Adieresis)
   (KRN O 305 R -3) (comment Aring)
   (KRN O 306 R -15) (comment AE)
   (STOP)
   (LABEL C T)
   (KRN O 270 R -68) (comment ydieresis)
   (KRN O 230 R 31) (comment Ydieresis)
   (KRN O 375 R -68) (comment yacute)
   (KRN O 335 R 31) (comment Yacute)
   (KRN O 371 R -68) (comment ugrave)
   (KRN O 374 R -68) (comment udieresis)
   (KRN O 373 R -68) (comment ucircumflex)
   (KRN O 372 R -68) (comment uacute)
   (KRN O 262 R -73) (comment scaron)
   (KRN O 222 R -1) (comment Scaron)
   (KRN O 365 R -73) (comment otilde)
   (KRN O 354 R -15) (comment igrave)
   (KRN O 357 R -15) (comment idieresis)
   (KRN O 356 R -15) (comment icircumflex)
   (KRN O 355 R -15) (comment iacute)
   (KRN O 350 R -75) (comment egrave)
   (KRN O 353 R -75) (comment edieresis)
   (KRN O 352 R -75) (comment ecircumflex)
   (KRN O 351 R -75) (comment eacute)
   (KRN O 347 R -68) (comment ccedilla)
   (KRN O 307 R -13) (comment Ccedilla)
   (KRN O 345 R -68) (comment aring)
   (KRN O 54 R -56) (comment comma)
   (KRN O 55 R -53) (comment hyphen)
   (KRN O 56 R -59) (comment period)
   (KRN O 72 R -53) (comment colon)
   (KRN O 73 R -41) (comment semicolon)
   (KRN C A R -33)
   (KRN C C R -13)
   (KRN C G R -4)
   (KRN C J R -38)
   (KRN C O R -20)
   (KRN C S R -1)
   (KRN C V R 39)
   (KRN C W R 41)
   (KRN C Y R 31)
   (KRN C a R -68)
   (KRN C c R -68)
   (KRN C e R -75)
   (KRN C g R -80)
   (KRN C i R -15)
   (KRN C j R -17)
   (KRN C o R -73)
   (KRN C r R -81)
   (KRN C s R -73)
   (KRN C u R -68)
   (KRN C v R -69)
   (KRN C w R -67)
   (KRN C y R -68)
   (KRN O 23 R -84) (comment guillemotleft)
   (KRN O 300 R -33) (comment Agrave)
   (KRN O 301 R -33) (comment Aacute)
   (KRN O 302 R -33) (comment Acircumflex)
   (KRN O 303 R -33) (comment Atilde)
   (KRN O 304 R -33) (comment Adieresis)
   (KRN O 305 R -33) (comment Aring)
   (KRN O 306 R -45) (comment AE)
   (KRN O 322 R -20) (comment Ograve)
   (KRN O 323 R -20) (comment Oacute)
   (KRN O 324 R -20) (comment Ocircumflex)
   (KRN O 325 R -20) (comment Otilde)
   (KRN O 326 R -20) (comment Odieresis)
   (KRN O 330 R -23) (comment Oslash)
   (KRN O 340 R -54) (comment agrave)
   (KRN O 341 R -70) (comment aacute)
   (KRN O 342 R -48) (comment acircumflex)
   (KRN O 343 R -40) (comment atilde)
   (KRN O 344 R -39) (comment adieresis)
   (KRN O 346 R -71) (comment ae)
   (KRN O 362 R -40) (comment ograve)
   (KRN O 363 R -57) (comment oacute)
   (KRN O 364 R -34) (comment ocircumflex)
   (KRN O 366 R -25) (comment odieresis)
   (KRN O 370 R -73) (comment oslash)
   (KRN O 327 R -6) (comment OE)
   (KRN O 16 R -83) (comment guilsinglleft)
   (STOP)
   (LABEL C U)
   (KRN O 361 R -19) (comment ntilde)
   (KRN O 300 R -38) (comment Agrave)
   (KRN O 54 R -16) (comment comma)
   (KRN O 56 R -22) (comment period)
   (KRN C A R -38)
   (KRN C m R -18)
   (KRN C n R -19)
   (KRN C p R -23)
   (KRN C r R -34)
   (KRN O 301 R -38) (comment Aacute)
   (KRN O 302 R -38) (comment Acircumflex)
   (KRN O 303 R -38) (comment Atilde)
   (KRN O 304 R -38) (comment Adieresis)
   (KRN O 305 R -38) (comment Aring)
   (KRN O 306 R -68) (comment AE)
   (STOP)
   (LABEL C V)
   (KRN O 270 R -16) (comment ydieresis)
   (KRN O 375 R -16) (comment yacute)
   (KRN O 371 R -37) (comment ugrave)
   (KRN O 374 R -37) (comment udieresis)
   (KRN O 373 R -37) (comment ucircumflex)
   (KRN O 372 R -37) (comment uacute)
   (KRN O 222 R -17) (comment Scaron)
   (KRN O 354 R -18) (comment igrave)
   (KRN O 357 R -18) (comment idieresis)
   (KRN O 356 R -18) (comment icircumflex)
   (KRN O 355 R -18) (comment iacute)
   (KRN O 353 R -57) (comment edieresis)
   (KRN O 352 R -57) (comment ecircumflex)
   (KRN O 307 R -29) (comment Ccedilla)
   (KRN O 54 R -56) (comment comma)
   (KRN O 55 R -31) (comment hyphen)
   (KRN O 56 R -65) (comment period)
   (KRN O 72 R -34) (comment colon)
   (KRN O 73 R -22) (comment semicolon)
   (KRN C A R -52)
   (KRN C C R -29)
   (KRN C G R -22)
   (KRN C O R -31)
   (KRN C S R -17)
   (KRN C T R 30)
   (KRN C a R -51)
   (KRN C e R -57)
   (KRN C g R -75)
   (KRN C i R -18)
   (KRN C o R -55)
   (KRN C r R -41)
   (KRN C u R -37)
   (KRN C y R -16)
   (KRN O 23 R -66) (comment guillemotleft)
   (KRN O 300 R -52) (comment Agrave)
   (KRN O 301 R -52) (comment Aacute)
   (KRN O 302 R -52) (comment Acircumflex)
   (KRN O 303 R -52) (comment Atilde)
   (KRN O 304 R -52) (comment Adieresis)
   (KRN O 305 R -52) (comment Aring)
   (KRN O 306 R -83) (comment AE)
   (KRN O 322 R -31) (comment Ograve)
   (KRN O 323 R -31) (comment Oacute)
   (KRN O 324 R -31) (comment Ocircumflex)
   (KRN O 325 R -31) (comment Otilde)
   (KRN O 326 R -31) (comment Odieresis)
   (KRN O 330 R -31) (comment Oslash)
   (KRN O 340 R -51) (comment agrave)
   (KRN O 341 R -51) (comment aacute)
   (KRN O 342 R -51) (comment acircumflex)
   (KRN O 343 R -51) (comment atilde)
   (KRN O 344 R -51) (comment adieresis)
   (KRN O 345 R -51) (comment aring)
   (KRN O 346 R -53) (comment ae)
   (KRN O 350 R -38) (comment egrave)
   (KRN O 351 R -57) (comment eacute)
   (KRN O 362 R -40) (comment ograve)
   (KRN O 363 R -55) (comment oacute)
   (KRN O 364 R -55) (comment ocircumflex)
   (KRN O 365 R -53) (comment otilde)
   (KRN O 366 R -48) (comment odieresis)
   (KRN O 370 R -56) (comment oslash)
   (KRN O 16 R -65) (comment guilsinglleft)
   (STOP)
   (LABEL C W)
   (KRN O 270 R -12) (comment ydieresis)
   (KRN O 375 R -12) (comment yacute)
   (KRN O 371 R -32) (comment ugrave)
   (KRN O 374 R -32) (comment udieresis)
   (KRN O 373 R -32) (comment ucircumflex)
   (KRN O 372 R -32) (comment uacute)
   (KRN O 222 R -17) (comment Scaron)
   (KRN O 354 R -19) (comment igrave)
   (KRN O 357 R -19) (comment idieresis)
   (KRN O 356 R -19) (comment icircumflex)
   (KRN O 355 R -19) (comment iacute)
   (KRN O 353 R -43) (comment edieresis)
   (KRN O 352 R -43) (comment ecircumflex)
   (KRN O 307 R -21) (comment Ccedilla)
   (KRN O 54 R -40) (comment comma)
   (KRN O 55 R -18) (comment hyphen)
   (KRN O 56 R -44) (comment period)
   (KRN O 72 R -24) (comment colon)
   (KRN O 73 R -12) (comment semicolon)
   (KRN C A R -42)
   (KRN C C R -21)
   (KRN C G R -14)
   (KRN C O R -23)
   (KRN C S R -17)
   (KRN C T R 28)
   (KRN C a R -42)
   (KRN C e R -43)
   (KRN C g R -60)
   (KRN C i R -19)
   (KRN C o R -41)
   (KRN C r R -37)
   (KRN C u R -32)
   (KRN C y R -12)
   (KRN O 23 R -51) (comment guillemotleft)
   (KRN O 300 R -42) (comment Agrave)
   (KRN O 301 R -42) (comment Aacute)
   (KRN O 302 R -42) (comment Acircumflex)
   (KRN O 303 R -42) (comment Atilde)
   (KRN O 304 R -42) (comment Adieresis)
   (KRN O 305 R -42) (comment Aring)
   (KRN O 306 R -79) (comment AE)
   (KRN O 322 R -23) (comment Ograve)
   (KRN O 323 R -23) (comment Oacute)
   (KRN O 324 R -23) (comment Ocircumflex)
   (KRN O 325 R -23) (comment Otilde)
   (KRN O 326 R -23) (comment Odieresis)
   (KRN O 330 R -23) (comment Oslash)
   (KRN O 340 R -42) (comment agrave)
   (KRN O 341 R -42) (comment aacute)
   (KRN O 342 R -42) (comment acircumflex)
   (KRN O 343 R -42) (comment atilde)
   (KRN O 344 R -42) (comment adieresis)
   (KRN O 345 R -42) (comment aring)
   (KRN O 346 R -44) (comment ae)
   (KRN O 350 R -40) (comment egrave)
   (KRN O 351 R -43) (comment eacute)
   (KRN O 362 R -41) (comment ograve)
   (KRN O 363 R -41) (comment oacute)
   (KRN O 364 R -41) (comment ocircumflex)
   (KRN O 365 R -41) (comment otilde)
   (KRN O 366 R -41) (comment odieresis)
   (KRN O 370 R -41) (comment oslash)
   (KRN O 16 R -50) (comment guilsinglleft)
   (STOP)
   (LABEL C X)
   (KRN O 270 R -65) (comment ydieresis)
   (KRN O 375 R -65) (comment yacute)
   (KRN O 371 R -7) (comment ugrave)
   (KRN O 374 R -7) (comment udieresis)
   (KRN O 373 R -7) (comment ucircumflex)
   (KRN O 372 R -7) (comment uacute)
   (KRN O 365 R -14) (comment otilde)
   (KRN O 325 R -32) (comment Otilde)
   (KRN O 370 R -14) (comment oslash)
   (KRN O 330 R -32) (comment Oslash)
   (KRN O 362 R -14) (comment ograve)
   (KRN O 322 R -32) (comment Ograve)
   (KRN O 366 R -14) (comment odieresis)
   (KRN O 364 R -14) (comment ocircumflex)
   (KRN O 324 R -32) (comment Ocircumflex)
   (KRN O 363 R -14) (comment oacute)
   (KRN O 323 R -32) (comment Oacute)
   (KRN O 350 R -16) (comment egrave)
   (KRN O 353 R -16) (comment edieresis)
   (KRN O 352 R -16) (comment ecircumflex)
   (KRN O 351 R -16) (comment eacute)
   (KRN O 307 R -35) (comment Ccedilla)
   (KRN O 343 R -3) (comment atilde)
   (KRN O 345 R -3) (comment aring)
   (KRN O 340 R -3) (comment agrave)
   (KRN O 344 R -3) (comment adieresis)
   (KRN O 342 R -3) (comment acircumflex)
   (KRN O 341 R -3) (comment aacute)
   (KRN O 55 R -27) (comment hyphen)
   (KRN C C R -35)
   (KRN C O R -32)
   (KRN C Q R -37)
   (KRN C a R -3)
   (KRN C e R -16)
   (KRN C o R -14)
   (KRN C u R -7)
   (KRN C y R -65)
   (KRN O 326 R -32) (comment Odieresis)
   (STOP)
   (LABEL C Y)
   (KRN O 371 R -53) (comment ugrave)
   (KRN O 374 R -53) (comment udieresis)
   (KRN O 373 R -53) (comment ucircumflex)
   (KRN O 372 R -53) (comment uacute)
   (KRN O 222 R -15) (comment Scaron)
   (KRN O 365 R -61) (comment otilde)
   (KRN O 362 R -61) (comment ograve)
   (KRN O 366 R -61) (comment odieresis)
   (KRN O 364 R -61) (comment ocircumflex)
   (KRN O 363 R -61) (comment oacute)
   (KRN O 354 R -16) (comment igrave)
   (KRN O 357 R -16) (comment idieresis)
   (KRN O 356 R -16) (comment icircumflex)
   (KRN O 355 R -16) (comment iacute)
   (KRN O 350 R -63) (comment egrave)
   (KRN O 353 R -63) (comment edieresis)
   (KRN O 352 R -63) (comment ecircumflex)
   (KRN O 351 R -63) (comment eacute)
   (KRN O 307 R -34) (comment Ccedilla)
   (KRN O 343 R -56) (comment atilde)
   (KRN O 345 R -56) (comment aring)
   (KRN O 340 R -56) (comment agrave)
   (KRN O 344 R -56) (comment adieresis)
   (KRN O 342 R -56) (comment acircumflex)
   (KRN O 341 R -56) (comment aacute)
   (KRN O 54 R -50) (comment comma)
   (KRN O 55 R -47) (comment hyphen)
   (KRN O 56 R -53) (comment period)
   (KRN O 72 R -40) (comment colon)
   (KRN O 73 R -29) (comment semicolon)
   (KRN C A R -27)
   (KRN C C R -34)
   (KRN C G R -27)
   (KRN C O R -36)
   (KRN C S R -15)
   (KRN C T R 30)
   (KRN C a R -56)
   (KRN C e R -63)
   (KRN C g R -82)
   (KRN C i R -16)
   (KRN C o R -61)
   (KRN C p R -53)
   (KRN C u R -53)
   (KRN C v R -31)
   (KRN O 23 R -78) (comment guillemotleft)
   (KRN O 300 R -27) (comment Agrave)
   (KRN O 301 R -27) (comment Aacute)
   (KRN O 302 R -27) (comment Acircumflex)
   (KRN O 303 R -27) (comment Atilde)
   (KRN O 304 R -27) (comment Adieresis)
   (KRN O 305 R -27) (comment Aring)
   (KRN O 306 R -38) (comment AE)
   (KRN O 322 R -36) (comment Ograve)
   (KRN O 323 R -36) (comment Oacute)
   (KRN O 324 R -36) (comment Ocircumflex)
   (KRN O 325 R -36) (comment Otilde)
   (KRN O 326 R -36) (comment Odieresis)
   (KRN O 330 R -36) (comment Oslash)
   (KRN O 346 R -59) (comment ae)
   (KRN O 370 R -62) (comment oslash)
   (KRN O 16 R -77) (comment guilsinglleft)
   (STOP)
   (LABEL C Z)
   (KRN O 270 R -7) (comment ydieresis)
   (KRN O 375 R -7) (comment yacute)
   (KRN C w R 5)
   (KRN C y R -7)
   (STOP)
   (LABEL O 140) (comment quoteleft)
   (LIG O 140 O 20)
   (KRN O 230 R -12) (comment Ydieresis)
   (KRN O 335 R -12) (comment Yacute)
   (KRN O 303 R -64) (comment Atilde)
   (KRN C A R -64)
   (KRN C T R 3)
   (KRN C V R 1)
   (KRN C W R 3)
   (KRN C Y R -12)
   (KRN O 300 R -64) (comment Agrave)
   (KRN O 301 R -64) (comment Aacute)
   (KRN O 302 R -64) (comment Acircumflex)
   (KRN O 304 R -64) (comment Adieresis)
   (KRN O 305 R -64) (comment Aring)
   (KRN O 306 R -112) (comment AE)
   (STOP)
   (LABEL C a)
   (KRN O 270 R 2) (comment ydieresis)
   (KRN O 375 R 2) (comment yacute)
   (KRN C j R -3)
   (KRN C w R 3)
   (KRN C y R 2)
   (KRN O 47 R -22) (comment quoteright)
   (STOP)
   (LABEL C b)
   (KRN O 270 R -2) (comment ydieresis)
   (KRN O 375 R -2) (comment yacute)
   (KRN C v R -7)
   (KRN C w R -5)
   (KRN C y R -2)
   (STOP)
   (LABEL C c)
   (KRN C h R -26)
   (KRN C k R -28)
   (STOP)
   (LABEL C e)
   (KRN O 270 R 3) (comment ydieresis)
   (KRN O 375 R 3) (comment yacute)
   (KRN C t R -15)
   (KRN C w R 2)
   (KRN C x R -12)
   (KRN C y R 3)
   (KRN O 47 R -16) (comment quoteright)
   (STOP)
   (LABEL C f)
   (LIG C f O 33)
   (LIG C l O 35)
   (LIG C i O 34)
   (KRN O 262 R -17) (comment scaron)
   (KRN O 365 R -14) (comment otilde)
   (KRN O 353 R -21) (comment edieresis)
   (KRN O 343 R -14) (comment atilde)
   (KRN O 340 R -14) (comment agrave)
   (KRN O 342 R -14) (comment acircumflex)
   (KRN C a R -14)
   (KRN C e R -21)
   (KRN C j R 14)
   (KRN C o R -14)
   (KRN C s R -17)
   (KRN C t R 18)
   (KRN O 341 R -14) (comment aacute)
   (KRN O 344 R -10) (comment adieresis)
   (KRN O 345 R -14) (comment aring)
   (KRN O 346 R -17) (comment ae)
   (KRN O 350 R -9) (comment egrave)
   (KRN O 351 R -21) (comment eacute)
   (KRN O 352 R -21) (comment ecircumflex)
   (KRN O 362 R -11) (comment ograve)
   (KRN O 363 R -19) (comment oacute)
   (KRN O 364 R -19) (comment ocircumflex)
   (KRN O 366 R 3) (comment odieresis)
   (KRN O 370 R -20) (comment oslash)
   (KRN O 367 R -10) (comment oe)
   (KRN O 47 R 17) (comment quoteright)
   (STOP)
   (LABEL C g)
   (KRN O 343 R -30) (comment atilde)
   (KRN O 340 R -30) (comment agrave)
   (KRN O 342 R -30) (comment acircumflex)
   (KRN O 341 R -30) (comment aacute)
   (KRN C a R -30)
   (KRN C e R -33)
   (KRN C l R -34)
   (KRN C r R -21)
   (KRN O 344 R -30) (comment adieresis)
   (KRN O 345 R -30) (comment aring)
   (KRN O 346 R -33) (comment ae)
   (KRN O 350 R -33) (comment egrave)
   (KRN O 351 R -33) (comment eacute)
   (KRN O 352 R -33) (comment ecircumflex)
   (KRN O 353 R -33) (comment edieresis)
   (KRN O 363 R -31) (comment oacute)
   (KRN O 366 R -31) (comment odieresis)
   (STOP)
   (LABEL C h)
   (KRN O 270 R -4) (comment ydieresis)
   (KRN O 375 R -4) (comment yacute)
   (KRN C y R -4)
   (KRN O 47 R -26) (comment quoteright)
   (STOP)
   (LABEL C i)
   (KRN C T R -11)
   (KRN C j R -23)
   (STOP)
   (LABEL C k)
   (KRN O 371 R 8) (comment ugrave)
   (KRN O 373 R 8) (comment ucircumflex)
   (KRN O 372 R 8) (comment uacute)
   (KRN O 262 R 6) (comment scaron)
   (KRN O 365 R 6) (comment otilde)
   (KRN O 370 R 6) (comment oslash)
   (KRN O 362 R 6) (comment ograve)
   (KRN O 364 R 6) (comment ocircumflex)
   (KRN O 353 R 4) (comment edieresis)
   (KRN O 352 R 4) (comment ecircumflex)
   (KRN O 343 R 12) (comment atilde)
   (KRN O 340 R 12) (comment agrave)
   (KRN O 342 R 12) (comment acircumflex)
   (KRN O 54 R 29) (comment comma)
   (KRN O 55 R -34) (comment hyphen)
   (KRN O 56 R 26) (comment period)
   (KRN C a R 12)
   (KRN C e R 4)
   (KRN C g R -27)
   (KRN C o R 6)
   (KRN C s R 6)
   (KRN C u R 8)
   (KRN O 341 R 12) (comment aacute)
   (KRN O 344 R 12) (comment adieresis)
   (KRN O 345 R 12) (comment aring)
   (KRN O 346 R 9) (comment ae)
   (KRN O 350 R 4) (comment egrave)
   (KRN O 351 R 4) (comment eacute)
   (KRN O 363 R 6) (comment oacute)
   (KRN O 366 R 6) (comment odieresis)
   (KRN O 374 R 8) (comment udieresis)
   (STOP)
   (LABEL C l)
   (KRN O 270 R -10) (comment ydieresis)
   (KRN O 375 R -10) (comment yacute)
   (KRN C v R -11)
   (KRN C y R -10)
   (STOP)
   (LABEL C m)
   (KRN O 270 R -3) (comment ydieresis)
   (KRN O 375 R -3) (comment yacute)
   (KRN C p R 3)
   (KRN C v R -6)
   (KRN C w R -4)
   (KRN C y R -3)
   (STOP)
   (LABEL C n)
   (KRN O 270 R -7) (comment ydieresis)
   (KRN O 375 R -7) (comment yacute)
   (KRN C T R -41)
   (KRN C v R -10)
   (KRN C w R -7)
   (KRN C y R -7)
   (KRN O 47 R -28) (comment quoteright)
   (STOP)
   (LABEL C o)
   (KRN O 270 R -8) (comment ydieresis)
   (KRN O 375 R -8) (comment yacute)
   (KRN C T R -50)
   (KRN C t R -5)
   (KRN C v R -14)
   (KRN C w R -12)
   (KRN C x R -27)
   (KRN C y R -8)
   (KRN O 47 R -19) (comment quoteright)
   (STOP)
   (LABEL C p)
   (KRN O 270 R -4) (comment ydieresis)
   (KRN O 375 R -4) (comment yacute)
   (KRN C t R -5)
   (KRN C y R -4)
   (STOP)
   (LABEL C q)
   (KRN O 371 R -2) (comment ugrave)
   (KRN O 374 R -2) (comment udieresis)
   (KRN O 373 R -2) (comment ucircumflex)
   (KRN O 372 R -2) (comment uacute)
   (KRN O 347 R -2) (comment ccedilla)
   (KRN C c R -2)
   (KRN C u R -2)
   (STOP)
   (LABEL C r)
   (KRN O 272 R -1) (comment zcaron)
   (KRN O 270 R 31) (comment ydieresis)
   (KRN O 375 R 31) (comment yacute)
   (KRN O 371 R 11) (comment ugrave)
   (KRN O 374 R 11) (comment udieresis)
   (KRN O 373 R 11) (comment ucircumflex)
   (KRN O 372 R 11) (comment uacute)
   (KRN O 262 R -17) (comment scaron)
   (KRN O 365 R -28) (comment otilde)
   (KRN O 361 R 16) (comment ntilde)
   (KRN O 354 R 8) (comment igrave)
   (KRN O 357 R 8) (comment idieresis)
   (KRN O 356 R 8) (comment icircumflex)
   (KRN O 355 R 8) (comment iacute)
   (KRN O 353 R -31) (comment edieresis)
   (KRN O 343 R -28) (comment atilde)
   (KRN O 54 R -57) (comment comma)
   (KRN O 55 R -44) (comment hyphen)
   (KRN O 56 R -62) (comment period)
   (KRN O 72 R -25) (comment colon)
   (KRN O 73 R -19) (comment semicolon)
   (KRN C a R -28)
   (KRN C c R -25)
   (KRN C d R -29)
   (KRN C e R -31)
   (KRN C f R 22)
   (KRN C g R -24)
   (KRN C h R -17)
   (KRN C i R 8)
   (KRN C j R 3)
   (KRN C k R -16)
   (KRN C l R -21)
   (KRN C m R 17)
   (KRN C n R 16)
   (KRN C o R -28)
   (KRN C p R 11)
   (KRN C q R -29)
   (KRN C r R 3)
   (KRN C s R -17)
   (KRN C t R 12)
   (KRN C u R 11)
   (KRN C v R 29)
   (KRN C w R 31)
   (KRN C x R 7)
   (KRN C y R 31)
   (KRN C z R -1)
   (KRN O 340 R -28) (comment agrave)
   (KRN O 341 R -28) (comment aacute)
   (KRN O 342 R -28) (comment acircumflex)
   (KRN O 344 R -28) (comment adieresis)
   (KRN O 345 R -28) (comment aring)
   (KRN O 346 R -34) (comment ae)
   (KRN O 347 R -20) (comment ccedilla)
   (KRN O 350 R -31) (comment egrave)
   (KRN O 351 R -31) (comment eacute)
   (KRN O 352 R -31) (comment ecircumflex)
   (KRN O 362 R -28) (comment ograve)
   (KRN O 363 R -28) (comment oacute)
   (KRN O 364 R -28) (comment ocircumflex)
   (KRN O 366 R -28) (comment odieresis)
   (KRN O 370 R -29) (comment oslash)
   (KRN O 367 R -23) (comment oe)
   (STOP)
   (LABEL C s)
   (KRN C t R -6)
   (KRN O 47 R -13) (comment quoteright)
   (STOP)
   (LABEL C t)
   (KRN O 222 R -2) (comment Scaron)
   (KRN O 365 R -8) (comment otilde)
   (KRN O 370 R -8) (comment oslash)
   (KRN O 362 R -8) (comment ograve)
   (KRN O 364 R -8) (comment ocircumflex)
   (KRN O 350 R -10) (comment egrave)
   (KRN O 353 R -10) (comment edieresis)
   (KRN O 352 R -10) (comment ecircumflex)
   (KRN O 343 R -3) (comment atilde)
   (KRN O 340 R -3) (comment agrave)
   (KRN O 342 R -3) (comment acircumflex)
   (KRN O 72 R 5) (comment colon)
   (KRN O 73 R 17) (comment semicolon)
   (KRN C S R -2)
   (KRN C a R -3)
   (KRN C e R -10)
   (KRN C h R -4)
   (KRN C o R -8)
   (KRN O 341 R -6) (comment aacute)
   (KRN O 344 R -6) (comment adieresis)
   (KRN O 345 R -6) (comment aring)
   (KRN O 346 R -9) (comment ae)
   (KRN O 351 R -10) (comment eacute)
   (KRN O 363 R -8) (comment oacute)
   (KRN O 366 R -8) (comment odieresis)
   (KRN O 47 R -10) (comment quoteright)
   (STOP)
   (LABEL C u)
   (KRN O 47 R -21) (comment quoteright)
   (STOP)
   (LABEL C v)
   (KRN O 262 R -24) (comment scaron)
   (KRN O 365 R -15) (comment otilde)
   (KRN O 364 R -15) (comment ocircumflex)
   (KRN O 353 R -20) (comment edieresis)
   (KRN O 347 R -16) (comment ccedilla)
   (KRN O 54 R -38) (comment comma)
   (KRN O 55 R 4) (comment hyphen)
   (KRN O 56 R -40) (comment period)
   (KRN O 72 R -7) (comment colon)
   (KRN O 73 R 4) (comment semicolon)
   (KRN C a R -14)
   (KRN C c R -16)
   (KRN C e R -20)
   (KRN C g R -37)
   (KRN C l R -22)
   (KRN C o R -15)
   (KRN C s R -24)
   (KRN O 340 R -17) (comment agrave)
   (KRN O 341 R -17) (comment aacute)
   (KRN O 342 R -17) (comment acircumflex)
   (KRN O 343 R -17) (comment atilde)
   (KRN O 344 R -17) (comment adieresis)
   (KRN O 345 R -17) (comment aring)
   (KRN O 346 R -20) (comment ae)
   (KRN O 350 R -20) (comment egrave)
   (KRN O 351 R -20) (comment eacute)
   (KRN O 352 R -20) (comment ecircumflex)
   (KRN O 362 R -18) (comment ograve)
   (KRN O 363 R -18) (comment oacute)
   (KRN O 366 R -18) (comment odieresis)
   (KRN O 370 R -19) (comment oslash)
   (STOP)
   (LABEL C w)
   (KRN O 262 R -25) (comment scaron)
   (KRN O 365 R -19) (comment otilde)
   (KRN O 364 R -19) (comment ocircumflex)
   (KRN O 353 R -21) (comment edieresis)
   (KRN O 347 R -17) (comment ccedilla)
   (KRN O 54 R -38) (comment comma)
   (KRN O 55 R 1) (comment hyphen)
   (KRN O 56 R -41) (comment period)
   (KRN O 72 R -8) (comment colon)
   (KRN C a R -18)
   (KRN C c R -17)
   (KRN C e R -21)
   (KRN C g R -37)
   (KRN C l R -22)
   (KRN C o R -19)
   (KRN C s R -25)
   (KRN O 340 R -18) (comment agrave)
   (KRN O 341 R -18) (comment aacute)
   (KRN O 342 R -18) (comment acircumflex)
   (KRN O 343 R -18) (comment atilde)
   (KRN O 344 R -18) (comment adieresis)
   (KRN O 345 R -18) (comment aring)
   (KRN O 346 R -21) (comment ae)
   (KRN O 350 R -21) (comment egrave)
   (KRN O 351 R -21) (comment eacute)
   (KRN O 352 R -21) (comment ecircumflex)
   (KRN O 362 R -19) (comment ograve)
   (KRN O 363 R -19) (comment oacute)
   (KRN O 366 R -19) (comment odieresis)
   (KRN O 370 R -19) (comment oslash)
   (STOP)
   (LABEL C x)
   (KRN O 365 R -1) (comment otilde)
   (KRN O 370 R -1) (comment oslash)
   (KRN O 362 R -1) (comment ograve)
   (KRN O 366 R -1) (comment odieresis)
   (KRN O 364 R -1) (comment ocircumflex)
   (KRN O 363 R -1) (comment oacute)
   (KRN O 350 R -3) (comment egrave)
   (KRN O 353 R -3) (comment edieresis)
   (KRN O 352 R -3) (comment ecircumflex)
   (KRN O 347 R -3) (comment ccedilla)
   (KRN O 343 R 4) (comment atilde)
   (KRN O 345 R 4) (comment aring)
   (KRN O 340 R 4) (comment agrave)
   (KRN O 344 R 4) (comment adieresis)
   (KRN O 342 R 4) (comment acircumflex)
   (KRN O 341 R 4) (comment aacute)
   (KRN C a R 4)
   (KRN C c R -3)
   (KRN C e R -3)
   (KRN C o R -1)
   (KRN O 351 R -3) (comment eacute)
   (STOP)
   (LABEL C y)
   (KRN O 262 R -13) (comment scaron)
   (KRN O 365 R -5) (comment otilde)
   (KRN O 364 R -5) (comment ocircumflex)
   (KRN O 353 R -7) (comment edieresis)
   (KRN O 347 R -3) (comment ccedilla)
   (KRN O 54 R -12) (comment comma)
   (KRN O 55 R 14) (comment hyphen)
   (KRN O 56 R -16) (comment period)
   (KRN O 72 R 5) (comment colon)
   (KRN O 73 R 12) (comment semicolon)
   (KRN C a R -3)
   (KRN C c R -3)
   (KRN C e R -7)
   (KRN C g R -24)
   (KRN C l R -9)
   (KRN C o R -5)
   (KRN C s R -13)
   (KRN O 340 R -3) (comment agrave)
   (KRN O 341 R -3) (comment aacute)
   (KRN O 342 R -3) (comment acircumflex)
   (KRN O 343 R -3) (comment atilde)
   (KRN O 344 R -3) (comment adieresis)
   (KRN O 345 R -3) (comment aring)
   (KRN O 346 R -6) (comment ae)
   (KRN O 350 R -7) (comment egrave)
   (KRN O 351 R -7) (comment eacute)
   (KRN O 352 R -7) (comment ecircumflex)
   (KRN O 362 R -5) (comment ograve)
   (KRN O 363 R -5) (comment oacute)
   (KRN O 366 R -5) (comment odieresis)
   (KRN O 370 R -5) (comment oslash)
   (STOP)
   (LABEL O 222) (comment Scaron)
   (KRN O 230 R -2) (comment Ydieresis)
   (KRN O 335 R -2) (comment Yacute)
   (KRN O 306 R -15) (comment AE)
   (KRN O 305 R -3) (comment Aring)
   (KRN O 304 R -3) (comment Adieresis)
   (KRN O 301 R -3) (comment Aacute)
   (KRN C t R -1)
   (KRN C Y R -2)
   (KRN C W R 7)
   (KRN C V R 4)
   (KRN C A R -3)
   (KRN O 302 R -3) (comment Acircumflex)
   (KRN O 300 R -3) (comment Agrave)
   (KRN O 303 R -3) (comment Atilde)
   (STOP)
   (LABEL O 230) (comment Ydieresis)
   (KRN O 16 R -77) (comment guilsinglleft)
   (KRN O 370 R -62) (comment oslash)
   (KRN O 346 R -59) (comment ae)
   (KRN O 330 R -36) (comment Oslash)
   (KRN O 326 R -36) (comment Odieresis)
   (KRN O 325 R -36) (comment Otilde)
   (KRN O 324 R -36) (comment Ocircumflex)
   (KRN O 323 R -36) (comment Oacute)
   (KRN O 322 R -36) (comment Ograve)
   (KRN O 306 R -38) (comment AE)
   (KRN O 305 R -27) (comment Aring)
   (KRN O 304 R -27) (comment Adieresis)
   (KRN O 303 R -27) (comment Atilde)
   (KRN O 302 R -27) (comment Acircumflex)
   (KRN O 301 R -27) (comment Aacute)
   (KRN O 300 R -27) (comment Agrave)
   (KRN O 23 R -78) (comment guillemotleft)
   (KRN C v R -31)
   (KRN C u R -53)
   (KRN C p R -53)
   (KRN C o R -61)
   (KRN C i R -16)
   (KRN C g R -82)
   (KRN C e R -63)
   (KRN C a R -56)
   (KRN C T R 30)
   (KRN C S R -15)
   (KRN C O R -36)
   (KRN C G R -27)
   (KRN C C R -34)
   (KRN C A R -27)
   (KRN O 73 R -29) (comment semicolon)
   (KRN O 72 R -40) (comment colon)
   (KRN O 56 R -53) (comment period)
   (KRN O 55 R -47) (comment hyphen)
   (KRN O 54 R -50) (comment comma)
   (KRN O 341 R -56) (comment aacute)
   (KRN O 342 R -56) (comment acircumflex)
   (KRN O 344 R -56) (comment adieresis)
   (KRN O 340 R -56) (comment agrave)
   (KRN O 345 R -56) (comment aring)
   (KRN O 343 R -56) (comment atilde)
   (KRN O 307 R -34) (comment Ccedilla)
   (KRN O 351 R -63) (comment eacute)
   (KRN O 352 R -63) (comment ecircumflex)
   (KRN O 353 R -63) (comment edieresis)
   (KRN O 350 R -63) (comment egrave)
   (KRN O 355 R -16) (comment iacute)
   (KRN O 356 R -16) (comment icircumflex)
   (KRN O 357 R -16) (comment idieresis)
   (KRN O 354 R -16) (comment igrave)
   (KRN O 363 R -61) (comment oacute)
   (KRN O 364 R -61) (comment ocircumflex)
   (KRN O 366 R -61) (comment odieresis)
   (KRN O 362 R -61) (comment ograve)
   (KRN O 365 R -61) (comment otilde)
   (KRN O 222 R -15) (comment Scaron)
   (KRN O 372 R -53) (comment uacute)
   (KRN O 373 R -53) (comment ucircumflex)
   (KRN O 374 R -53) (comment udieresis)
   (KRN O 371 R -53) (comment ugrave)
   (STOP)
   (LABEL O 232) (comment Zcaron)
   (KRN C y R -7)
   (KRN C w R 5)
   (KRN O 375 R -7) (comment yacute)
   (KRN O 270 R -7) (comment ydieresis)
   (STOP)
   (LABEL O 262) (comment scaron)
   (KRN O 47 R -13) (comment quoteright)
   (KRN C t R -6)
   (STOP)
   (LABEL O 270) (comment ydieresis)
   (KRN O 370 R -5) (comment oslash)
   (KRN O 366 R -5) (comment odieresis)
   (KRN O 363 R -5) (comment oacute)
   (KRN O 362 R -5) (comment ograve)
   (KRN O 352 R -7) (comment ecircumflex)
   (KRN O 351 R -7) (comment eacute)
   (KRN O 350 R -7) (comment egrave)
   (KRN O 346 R -6) (comment ae)
   (KRN O 345 R -3) (comment aring)
   (KRN O 344 R -3) (comment adieresis)
   (KRN O 343 R -3) (comment atilde)
   (KRN O 342 R -3) (comment acircumflex)
   (KRN O 341 R -3) (comment aacute)
   (KRN O 340 R -3) (comment agrave)
   (KRN C s R -13)
   (KRN C o R -5)
   (KRN C l R -9)
   (KRN C g R -24)
   (KRN C e R -7)
   (KRN C c R -3)
   (KRN C a R -3)
   (KRN O 73 R 12) (comment semicolon)
   (KRN O 72 R 5) (comment colon)
   (KRN O 56 R -16) (comment period)
   (KRN O 55 R 14) (comment hyphen)
   (KRN O 54 R -12) (comment comma)
   (KRN O 347 R -3) (comment ccedilla)
   (KRN O 353 R -7) (comment edieresis)
   (KRN O 364 R -5) (comment ocircumflex)
   (KRN O 365 R -5) (comment otilde)
   (KRN O 262 R -13) (comment scaron)
   (STOP)
   (LABEL O 300) (comment Agrave)
   (KRN O 270 R -54) (comment ydieresis)
   (KRN O 230 R -20) (comment Ydieresis)
   (KRN O 375 R -54) (comment yacute)
   (KRN O 335 R -20) (comment Yacute)
   (KRN O 365 R -16) (comment otilde)
   (KRN O 325 R -37) (comment Otilde)
   (KRN O 370 R -16) (comment oslash)
   (KRN O 330 R -37) (comment Oslash)
   (KRN O 362 R -16) (comment ograve)
   (KRN O 322 R -37) (comment Ograve)
   (KRN O 364 R -16) (comment ocircumflex)
   (KRN O 324 R -37) (comment Ocircumflex)
   (KRN O 363 R -16) (comment oacute)
   (KRN O 323 R -37) (comment Oacute)
   (KRN O 350 R -18) (comment egrave)
   (KRN O 353 R -18) (comment edieresis)
   (KRN O 352 R -18) (comment ecircumflex)
   (KRN O 351 R -18) (comment eacute)
   (KRN O 343 R -5) (comment atilde)
   (KRN O 345 R -5) (comment aring)
   (KRN O 340 R -5) (comment agrave)
   (KRN O 16 R -28) (comment guilsinglleft)
   (KRN O 21 R -77) (comment quotedblright)
   (KRN O 47 R -77) (comment quoteright)
   (KRN O 374 R -9) (comment udieresis)
   (KRN O 373 R -9) (comment ucircumflex)
   (KRN O 372 R -9) (comment uacute)
   (KRN O 371 R -9) (comment ugrave)
   (KRN O 366 R -16) (comment odieresis)
   (KRN O 347 R -19) (comment ccedilla)
   (KRN O 334 R -46) (comment Udieresis)
   (KRN O 333 R -46) (comment Ucircumflex)
   (KRN O 332 R -46) (comment Uacute)
   (KRN O 331 R -46) (comment Ugrave)
   (KRN O 326 R -37) (comment Odieresis)
   (KRN O 307 R -36) (comment Ccedilla)
   (KRN O 23 R -29) (comment guillemotleft)
   (KRN C y R -54)
   (KRN C w R -32)
   (KRN C v R -35)
   (KRN C u R -9)
   (KRN C t R -7)
   (KRN C q R -11)
   (KRN C o R -16)
   (KRN C g R -31)
   (KRN C e R -18)
   (KRN C d R -4)
   (KRN C c R -17)
   (KRN C a R -5)
   (KRN O 341 R -5) (comment aacute)
   (KRN O 342 R -5) (comment acircumflex)
   (KRN O 344 R -5) (comment adieresis)
   (KRN O 54 R 19) (comment comma)
   (KRN O 56 R 19) (comment period)
   (KRN C C R -36)
   (KRN C G R -29)
   (KRN C O R -37)
   (KRN C Q R -36)
   (KRN C T R -14)
   (KRN C U R -46)
   (KRN C V R -65)
   (KRN C W R -59)
   (KRN C Y R -20)
   (STOP)
   (LABEL O 301) (comment Aacute)
   (KRN O 270 R -54) (comment ydieresis)
   (KRN O 230 R -20) (comment Ydieresis)
   (KRN O 375 R -54) (comment yacute)
   (KRN O 335 R -20) (comment Yacute)
   (KRN O 365 R -16) (comment otilde)
   (KRN O 325 R -37) (comment Otilde)
   (KRN O 370 R -16) (comment oslash)
   (KRN O 330 R -37) (comment Oslash)
   (KRN O 362 R -16) (comment ograve)
   (KRN O 322 R -37) (comment Ograve)
   (KRN O 364 R -16) (comment ocircumflex)
   (KRN O 324 R -37) (comment Ocircumflex)
   (KRN O 363 R -16) (comment oacute)
   (KRN O 323 R -37) (comment Oacute)
   (KRN O 350 R -18) (comment egrave)
   (KRN O 353 R -18) (comment edieresis)
   (KRN O 352 R -18) (comment ecircumflex)
   (KRN O 351 R -18) (comment eacute)
   (KRN O 343 R -5) (comment atilde)
   (KRN O 345 R -5) (comment aring)
   (KRN O 340 R -5) (comment agrave)
   (KRN O 344 R -5) (comment adieresis)
   (KRN O 342 R -5) (comment acircumflex)
   (KRN O 341 R -5) (comment aacute)
   (KRN O 374 R -9) (comment udieresis)
   (KRN O 373 R -9) (comment ucircumflex)
   (KRN O 372 R -9) (comment uacute)
   (KRN O 371 R -9) (comment ugrave)
   (KRN O 366 R -16) (comment odieresis)
   (KRN O 347 R -19) (comment ccedilla)
   (KRN O 334 R -46) (comment Udieresis)
   (KRN O 333 R -46) (comment Ucircumflex)
   (KRN O 332 R -46) (comment Uacute)
   (KRN O 331 R -46) (comment Ugrave)
   (KRN O 326 R -37) (comment Odieresis)
   (KRN O 307 R -36) (comment Ccedilla)
   (KRN O 54 R 19) (comment comma)
   (KRN O 56 R 19) (comment period)
   (KRN C C R -36)
   (KRN C G R -29)
   (KRN C O R -37)
   (KRN C Q R -36)
   (KRN C T R -14)
   (KRN C U R -46)
   (KRN C V R -65)
   (KRN C W R -59)
   (KRN C Y R -20)
   (KRN C a R -5)
   (KRN C c R -17)
   (KRN C d R -4)
   (KRN C e R -18)
   (KRN C g R -31)
   (KRN C o R -16)
   (KRN C q R -11)
   (KRN C t R -7)
   (KRN C u R -9)
   (KRN C v R -35)
   (KRN C w R -32)
   (KRN C y R -54)
   (KRN O 23 R -29) (comment guillemotleft)
   (KRN O 47 R -77) (comment quoteright)
   (KRN O 21 R -77) (comment quotedblright)
   (KRN O 16 R -28) (comment guilsinglleft)
   (STOP)
   (LABEL O 302) (comment Acircumflex)
   (KRN O 270 R -54) (comment ydieresis)
   (KRN O 230 R -20) (comment Ydieresis)
   (KRN O 375 R -54) (comment yacute)
   (KRN O 335 R -20) (comment Yacute)
   (KRN O 365 R -16) (comment otilde)
   (KRN O 325 R -37) (comment Otilde)
   (KRN O 370 R -16) (comment oslash)
   (KRN O 330 R -37) (comment Oslash)
   (KRN O 362 R -16) (comment ograve)
   (KRN O 322 R -37) (comment Ograve)
   (KRN O 364 R -16) (comment ocircumflex)
   (KRN O 324 R -37) (comment Ocircumflex)
   (KRN O 363 R -16) (comment oacute)
   (KRN O 323 R -37) (comment Oacute)
   (KRN O 350 R -18) (comment egrave)
   (KRN O 353 R -18) (comment edieresis)
   (KRN O 352 R -18) (comment ecircumflex)
   (KRN O 351 R -18) (comment eacute)
   (KRN O 343 R -5) (comment atilde)
   (KRN O 345 R -5) (comment aring)
   (KRN O 340 R -5) (comment agrave)
   (KRN O 344 R -5) (comment adieresis)
   (KRN O 342 R -5) (comment acircumflex)
   (KRN O 16 R -28) (comment guilsinglleft)
   (KRN O 21 R -77) (comment quotedblright)
   (KRN O 47 R -77) (comment quoteright)
   (KRN O 374 R -9) (comment udieresis)
   (KRN O 373 R -9) (comment ucircumflex)
   (KRN O 372 R -9) (comment uacute)
   (KRN O 371 R -9) (comment ugrave)
   (KRN O 366 R -16) (comment odieresis)
   (KRN O 347 R -19) (comment ccedilla)
   (KRN O 334 R -46) (comment Udieresis)
   (KRN O 333 R -46) (comment Ucircumflex)
   (KRN O 332 R -46) (comment Uacute)
   (KRN O 331 R -46) (comment Ugrave)
   (KRN O 326 R -37) (comment Odieresis)
   (KRN O 307 R -36) (comment Ccedilla)
   (KRN O 23 R -29) (comment guillemotleft)
   (KRN C y R -54)
   (KRN C w R -32)
   (KRN C v R -35)
   (KRN C u R -9)
   (KRN C t R -7)
   (KRN C q R -11)
   (KRN C o R -16)
   (KRN C g R -31)
   (KRN C e R -18)
   (KRN C d R -4)
   (KRN C c R -17)
   (KRN C a R -5)
   (KRN O 341 R -5) (comment aacute)
   (KRN O 54 R 19) (comment comma)
   (KRN O 56 R 19) (comment period)
   (KRN C C R -36)
   (KRN C G R -29)
   (KRN C O R -37)
   (KRN C Q R -36)
   (KRN C T R -14)
   (KRN C U R -46)
   (KRN C V R -65)
   (KRN C W R -59)
   (KRN C Y R -20)
   (STOP)
   (LABEL O 303) (comment Atilde)
   (KRN O 270 R -54) (comment ydieresis)
   (KRN O 230 R -20) (comment Ydieresis)
   (KRN O 375 R -54) (comment yacute)
   (KRN O 335 R -20) (comment Yacute)
   (KRN O 365 R -16) (comment otilde)
   (KRN O 325 R -37) (comment Otilde)
   (KRN O 370 R -16) (comment oslash)
   (KRN O 330 R -37) (comment Oslash)
   (KRN O 362 R -16) (comment ograve)
   (KRN O 322 R -37) (comment Ograve)
   (KRN O 364 R -16) (comment ocircumflex)
   (KRN O 324 R -37) (comment Ocircumflex)
   (KRN O 363 R -16) (comment oacute)
   (KRN O 323 R -37) (comment Oacute)
   (KRN O 350 R -18) (comment egrave)
   (KRN O 353 R -18) (comment edieresis)
   (KRN O 352 R -18) (comment ecircumflex)
   (KRN O 351 R -18) (comment eacute)
   (KRN O 343 R -5) (comment atilde)
   (KRN O 16 R -28) (comment guilsinglleft)
   (KRN O 21 R -77) (comment quotedblright)
   (KRN O 47 R -77) (comment quoteright)
   (KRN O 374 R -9) (comment udieresis)
   (KRN O 373 R -9) (comment ucircumflex)
   (KRN O 372 R -9) (comment uacute)
   (KRN O 371 R -9) (comment ugrave)
   (KRN O 366 R -16) (comment odieresis)
   (KRN O 347 R -19) (comment ccedilla)
   (KRN O 334 R -46) (comment Udieresis)
   (KRN O 333 R -46) (comment Ucircumflex)
   (KRN O 332 R -46) (comment Uacute)
   (KRN O 331 R -46) (comment Ugrave)
   (KRN O 326 R -37) (comment Odieresis)
   (KRN O 307 R -36) (comment Ccedilla)
   (KRN O 23 R -29) (comment guillemotleft)
   (KRN C y R -54)
   (KRN C w R -32)
   (KRN C v R -35)
   (KRN C u R -9)
   (KRN C t R -7)
   (KRN C q R -11)
   (KRN C o R -16)
   (KRN C g R -31)
   (KRN C e R -18)
   (KRN C d R -4)
   (KRN C c R -17)
   (KRN C a R -5)
   (KRN O 341 R -5) (comment aacute)
   (KRN O 342 R -5) (comment acircumflex)
   (KRN O 344 R -5) (comment adieresis)
   (KRN O 340 R -5) (comment agrave)
   (KRN O 345 R -5) (comment aring)
   (KRN O 54 R 20) (comment comma)
   (KRN O 56 R 17) (comment period)
   (KRN C C R -36)
   (KRN C G R -29)
   (KRN C O R -37)
   (KRN C Q R -36)
   (KRN C T R -14)
   (KRN C U R -45)
   (KRN C V R -66)
   (KRN C W R -59)
   (KRN C Y R -20)
   (STOP)
   (LABEL O 304) (comment Adieresis)
   (KRN O 270 R -54) (comment ydieresis)
   (KRN O 230 R -20) (comment Ydieresis)
   (KRN O 375 R -54) (comment yacute)
   (KRN O 335 R -20) (comment Yacute)
   (KRN O 365 R -16) (comment otilde)
   (KRN O 325 R -37) (comment Otilde)
   (KRN O 370 R -16) (comment oslash)
   (KRN O 330 R -37) (comment Oslash)
   (KRN O 362 R -16) (comment ograve)
   (KRN O 322 R -37) (comment Ograve)
   (KRN O 364 R -16) (comment ocircumflex)
   (KRN O 324 R -37) (comment Ocircumflex)
   (KRN O 363 R -16) (comment oacute)
   (KRN O 323 R -37) (comment Oacute)
   (KRN O 350 R -18) (comment egrave)
   (KRN O 353 R -18) (comment edieresis)
   (KRN O 352 R -18) (comment ecircumflex)
   (KRN O 351 R -18) (comment eacute)
   (KRN O 343 R -5) (comment atilde)
   (KRN O 345 R -5) (comment aring)
   (KRN O 340 R -5) (comment agrave)
   (KRN O 344 R -5) (comment adieresis)
   (KRN O 374 R -9) (comment udieresis)
   (KRN O 373 R -9) (comment ucircumflex)
   (KRN O 372 R -9) (comment uacute)
   (KRN O 371 R -9) (comment ugrave)
   (KRN O 366 R -16) (comment odieresis)
   (KRN O 347 R -19) (comment ccedilla)
   (KRN O 334 R -46) (comment Udieresis)
   (KRN O 333 R -46) (comment Ucircumflex)
   (KRN O 332 R -46) (comment Uacute)
   (KRN O 331 R -46) (comment Ugrave)
   (KRN O 326 R -37) (comment Odieresis)
   (KRN O 307 R -36) (comment Ccedilla)
   (KRN C e R -18)
   (KRN O 342 R -5) (comment acircumflex)
   (KRN O 341 R -5) (comment aacute)
   (KRN O 54 R 19) (comment comma)
   (KRN O 56 R 19) (comment period)
   (KRN C C R -36)
   (KRN C G R -29)
   (KRN C O R -37)
   (KRN C Q R -36)
   (KRN C T R -14)
   (KRN C U R -46)
   (KRN C V R -65)
   (KRN C W R -59)
   (KRN C Y R -20)
   (KRN C a R -5)
   (KRN C c R -17)
   (KRN C d R -4)
   (KRN C g R -31)
   (KRN C o R -16)
   (KRN C q R -11)
   (KRN C t R -7)
   (KRN C u R -9)
   (KRN C v R -35)
   (KRN C w R -32)
   (KRN C y R -54)
   (KRN O 23 R -29) (comment guillemotleft)
   (KRN O 47 R -77) (comment quoteright)
   (KRN O 21 R -77) (comment quotedblright)
   (KRN O 16 R -28) (comment guilsinglleft)
   (STOP)
   (LABEL O 305) (comment Aring)
   (KRN O 270 R -54) (comment ydieresis)
   (KRN O 230 R -20) (comment Ydieresis)
   (KRN O 375 R -54) (comment yacute)
   (KRN O 335 R -20) (comment Yacute)
   (KRN O 365 R -16) (comment otilde)
   (KRN O 325 R -37) (comment Otilde)
   (KRN O 370 R -16) (comment oslash)
   (KRN O 330 R -37) (comment Oslash)
   (KRN O 362 R -16) (comment ograve)
   (KRN O 322 R -37) (comment Ograve)
   (KRN O 364 R -16) (comment ocircumflex)
   (KRN O 324 R -37) (comment Ocircumflex)
   (KRN O 363 R -16) (comment oacute)
   (KRN O 323 R -37) (comment Oacute)
   (KRN O 350 R -18) (comment egrave)
   (KRN O 353 R -18) (comment edieresis)
   (KRN O 352 R -18) (comment ecircumflex)
   (KRN O 351 R -18) (comment eacute)
   (KRN O 343 R -5) (comment atilde)
   (KRN O 345 R -5) (comment aring)
   (KRN O 374 R -9) (comment udieresis)
   (KRN O 373 R -9) (comment ucircumflex)
   (KRN O 372 R -9) (comment uacute)
   (KRN O 371 R -9) (comment ugrave)
   (KRN O 366 R -16) (comment odieresis)
   (KRN O 347 R -19) (comment ccedilla)
   (KRN O 334 R -46) (comment Udieresis)
   (KRN O 333 R -46) (comment Ucircumflex)
   (KRN O 332 R -46) (comment Uacute)
   (KRN O 331 R -46) (comment Ugrave)
   (KRN O 326 R -37) (comment Odieresis)
   (KRN O 307 R -36) (comment Ccedilla)
   (KRN O 340 R -5) (comment agrave)
   (KRN O 344 R -5) (comment adieresis)
   (KRN O 342 R -5) (comment acircumflex)
   (KRN O 341 R -5) (comment aacute)
   (KRN O 54 R 19) (comment comma)
   (KRN O 56 R 19) (comment period)
   (KRN C C R -36)
   (KRN C G R -29)
   (KRN C O R -37)
   (KRN C Q R -36)
   (KRN C T R -14)
   (KRN C U R -46)
   (KRN C V R -65)
   (KRN C W R -59)
   (KRN C Y R -20)
   (KRN C a R -5)
   (KRN C c R -17)
   (KRN C d R -4)
   (KRN C e R -18)
   (KRN C g R -31)
   (KRN C o R -16)
   (KRN C q R -11)
   (KRN C t R -7)
   (KRN C u R -9)
   (KRN C v R -35)
   (KRN C w R -32)
   (KRN C y R -54)
   (KRN O 23 R -29) (comment guillemotleft)
   (KRN O 47 R -77) (comment quoteright)
   (KRN O 21 R -77) (comment quotedblright)
   (KRN O 16 R -28) (comment guilsinglleft)
   (STOP)
   (LABEL O 307) (comment Ccedilla)
   (KRN O 325 R -7) (comment Otilde)
   (KRN O 330 R -7) (comment Oslash)
   (KRN O 324 R -7) (comment Ocircumflex)
   (KRN O 326 R -7) (comment Odieresis)
   (KRN O 323 R -7) (comment Oacute)
   (KRN O 322 R -7) (comment Ograve)
   (KRN O 306 R -31) (comment AE)
   (KRN C O R -7)
   (KRN C K R -17)
   (KRN C H R -5)
   (KRN O 303 R -19) (comment Atilde)
   (KRN O 305 R -19) (comment Aring)
   (KRN O 300 R -19) (comment Agrave)
   (KRN O 304 R -19) (comment Adieresis)
   (KRN O 302 R -19) (comment Acircumflex)
   (KRN O 301 R -19) (comment Aacute)
   (KRN C A R -19)
   (STOP)
   (LABEL O 321) (comment Ntilde)
   (KRN O 371 R -11) (comment ugrave)
   (KRN O 373 R -11) (comment ucircumflex)
   (KRN O 372 R -11) (comment uacute)
   (KRN O 365 R -12) (comment otilde)
   (KRN O 325 R -2) (comment Otilde)
   (KRN O 330 R -2) (comment Oslash)
   (KRN O 362 R -12) (comment ograve)
   (KRN O 322 R -2) (comment Ograve)
   (KRN O 364 R -12) (comment ocircumflex)
   (KRN O 324 R -2) (comment Ocircumflex)
   (KRN O 374 R -11) (comment udieresis)
   (KRN O 370 R -13) (comment oslash)
   (KRN O 366 R -12) (comment odieresis)
   (KRN O 363 R -12) (comment oacute)
   (KRN O 351 R -14) (comment eacute)
   (KRN O 346 R -11) (comment ae)
   (KRN O 345 R -12) (comment aring)
   (KRN O 344 R -12) (comment adieresis)
   (KRN O 341 R -12) (comment aacute)
   (KRN O 326 R -2) (comment Odieresis)
   (KRN O 323 R -2) (comment Oacute)
   (KRN O 307 R -5) (comment Ccedilla)
   (KRN O 306 R -31) (comment AE)
   (KRN O 305 R -19) (comment Aring)
   (KRN O 304 R -19) (comment Adieresis)
   (KRN O 301 R -19) (comment Aacute)
   (KRN C u R -11)
   (KRN C o R -12)
   (KRN C e R -14)
   (KRN C a R -8)
   (KRN C O R -2)
   (KRN C G R 1)
   (KRN C C R -5)
   (KRN C A R -19)
   (KRN O 56 R -4) (comment period)
   (KRN O 54 R 1) (comment comma)
   (KRN O 302 R -19) (comment Acircumflex)
   (KRN O 342 R -8) (comment acircumflex)
   (KRN O 300 R -19) (comment Agrave)
   (KRN O 340 R -8) (comment agrave)
   (KRN O 303 R -19) (comment Atilde)
   (KRN O 343 R -8) (comment atilde)
   (KRN O 352 R -14) (comment ecircumflex)
   (KRN O 353 R -14) (comment edieresis)
   (KRN O 350 R -14) (comment egrave)
   (STOP)
   (LABEL O 322) (comment Ograve)
   (KRN O 230 R -34) (comment Ydieresis)
   (KRN O 335 R -34) (comment Yacute)
   (KRN O 306 R -53) (comment AE)
   (KRN O 305 R -16) (comment Aring)
   (KRN O 304 R -16) (comment Adieresis)
   (KRN O 301 R -16) (comment Aacute)
   (KRN C X R -26)
   (KRN C W R -23)
   (KRN C A R -16)
   (KRN O 302 R -16) (comment Acircumflex)
   (KRN O 300 R -16) (comment Agrave)
   (KRN O 303 R -16) (comment Atilde)
   (KRN C T R -5)
   (KRN C V R -29)
   (KRN C Y R -34)
   (STOP)
   (LABEL O 323) (comment Oacute)
   (KRN O 230 R -34) (comment Ydieresis)
   (KRN O 335 R -34) (comment Yacute)
   (KRN O 306 R -53) (comment AE)
   (KRN C X R -26)
   (KRN O 303 R -16) (comment Atilde)
   (KRN O 305 R -16) (comment Aring)
   (KRN O 300 R -16) (comment Agrave)
   (KRN O 304 R -16) (comment Adieresis)
   (KRN O 302 R -16) (comment Acircumflex)
   (KRN O 301 R -16) (comment Aacute)
   (KRN C A R -16)
   (KRN C T R -5)
   (KRN C V R -29)
   (KRN C W R -23)
   (KRN C Y R -34)
   (STOP)
   (LABEL O 324) (comment Ocircumflex)
   (KRN O 230 R -34) (comment Ydieresis)
   (KRN O 335 R -34) (comment Yacute)
   (KRN O 306 R -53) (comment AE)
   (KRN O 305 R -16) (comment Aring)
   (KRN O 304 R -16) (comment Adieresis)
   (KRN O 301 R -16) (comment Aacute)
   (KRN C X R -26)
   (KRN C W R -23)
   (KRN C A R -16)
   (KRN O 302 R -16) (comment Acircumflex)
   (KRN O 300 R -16) (comment Agrave)
   (KRN O 303 R -16) (comment Atilde)
   (KRN C T R -5)
   (KRN C V R -29)
   (KRN C Y R -34)
   (STOP)
   (LABEL O 325) (comment Otilde)
   (KRN O 230 R -34) (comment Ydieresis)
   (KRN O 335 R -34) (comment Yacute)
   (KRN O 306 R -53) (comment AE)
   (KRN O 305 R -16) (comment Aring)
   (KRN O 304 R -16) (comment Adieresis)
   (KRN O 301 R -16) (comment Aacute)
   (KRN C X R -26)
   (KRN C W R -23)
   (KRN C A R -16)
   (KRN O 302 R -16) (comment Acircumflex)
   (KRN O 300 R -16) (comment Agrave)
   (KRN O 303 R -16) (comment Atilde)
   (KRN C T R -5)
   (KRN C V R -29)
   (KRN C Y R -34)
   (STOP)
   (LABEL O 326) (comment Odieresis)
   (KRN O 230 R -34) (comment Ydieresis)
   (KRN O 335 R -34) (comment Yacute)
   (KRN O 306 R -53) (comment AE)
   (KRN O 303 R -16) (comment Atilde)
   (KRN O 305 R -16) (comment Aring)
   (KRN O 300 R -16) (comment Agrave)
   (KRN O 304 R -16) (comment Adieresis)
   (KRN O 302 R -16) (comment Acircumflex)
   (KRN O 301 R -16) (comment Aacute)
   (KRN C A R -16)
   (KRN C T R -5)
   (KRN C V R -29)
   (KRN C W R -23)
   (KRN C X R -26)
   (KRN C Y R -34)
   (STOP)
   (LABEL O 330) (comment Oslash)
   (KRN O 230 R -34) (comment Ydieresis)
   (KRN O 335 R -34) (comment Yacute)
   (KRN O 306 R -53) (comment AE)
   (KRN C Y R -34)
   (KRN C X R -26)
   (KRN C W R -23)
   (KRN C V R -29)
   (KRN C T R -5)
   (KRN O 303 R -16) (comment Atilde)
   (KRN O 305 R -16) (comment Aring)
   (KRN O 300 R -16) (comment Agrave)
   (KRN O 304 R -16) (comment Adieresis)
   (KRN O 302 R -16) (comment Acircumflex)
   (KRN O 301 R -16) (comment Aacute)
   (KRN C A R -16)
   (STOP)
   (LABEL O 331) (comment Ugrave)
   (KRN O 306 R -68) (comment AE)
   (KRN O 361 R -19) (comment ntilde)
   (KRN O 303 R -38) (comment Atilde)
   (KRN O 305 R -38) (comment Aring)
   (KRN O 300 R -38) (comment Agrave)
   (KRN O 304 R -38) (comment Adieresis)
   (KRN O 302 R -38) (comment Acircumflex)
   (KRN O 301 R -38) (comment Aacute)
   (KRN O 54 R -16) (comment comma)
   (KRN O 56 R -22) (comment period)
   (KRN C A R -38)
   (KRN C m R -18)
   (KRN C n R -19)
   (KRN C p R -23)
   (KRN C r R -34)
   (STOP)
   (LABEL O 332) (comment Uacute)
   (KRN O 306 R -68) (comment AE)
   (KRN O 361 R -19) (comment ntilde)
   (KRN O 303 R -38) (comment Atilde)
   (KRN O 305 R -38) (comment Aring)
   (KRN O 300 R -38) (comment Agrave)
   (KRN O 304 R -38) (comment Adieresis)
   (KRN O 302 R -38) (comment Acircumflex)
   (KRN O 301 R -38) (comment Aacute)
   (KRN O 54 R -16) (comment comma)
   (KRN O 56 R -22) (comment period)
   (KRN C A R -38)
   (KRN C m R -18)
   (KRN C n R -19)
   (KRN C p R -23)
   (KRN C r R -34)
   (STOP)
   (LABEL O 333) (comment Ucircumflex)
   (KRN O 306 R -68) (comment AE)
   (KRN C r R -34)
   (KRN C p R -23)
   (KRN C n R -19)
   (KRN C m R -18)
   (KRN O 56 R -22) (comment period)
   (KRN O 54 R -16) (comment comma)
   (KRN O 361 R -19) (comment ntilde)
   (KRN O 303 R -38) (comment Atilde)
   (KRN O 305 R -38) (comment Aring)
   (KRN O 300 R -38) (comment Agrave)
   (KRN O 304 R -38) (comment Adieresis)
   (KRN O 302 R -38) (comment Acircumflex)
   (KRN O 301 R -38) (comment Aacute)
   (KRN C A R -38)
   (STOP)
   (LABEL O 334) (comment Udieresis)
   (KRN O 306 R -68) (comment AE)
   (KRN O 361 R -19) (comment ntilde)
   (KRN O 303 R -38) (comment Atilde)
   (KRN O 305 R -38) (comment Aring)
   (KRN O 300 R -38) (comment Agrave)
   (KRN O 304 R -38) (comment Adieresis)
   (KRN O 302 R -38) (comment Acircumflex)
   (KRN O 301 R -38) (comment Aacute)
   (KRN O 54 R -16) (comment comma)
   (KRN O 56 R -22) (comment period)
   (KRN C A R -38)
   (KRN C b R 1)
   (KRN C m R -18)
   (KRN C n R -19)
   (KRN C p R -23)
   (KRN C r R -34)
   (STOP)
   (LABEL O 335) (comment Yacute)
   (KRN O 16 R -77) (comment guilsinglleft)
   (KRN O 370 R -62) (comment oslash)
   (KRN O 346 R -59) (comment ae)
   (KRN O 330 R -36) (comment Oslash)
   (KRN O 326 R -36) (comment Odieresis)
   (KRN O 325 R -36) (comment Otilde)
   (KRN O 324 R -36) (comment Ocircumflex)
   (KRN O 323 R -36) (comment Oacute)
   (KRN O 322 R -36) (comment Ograve)
   (KRN O 306 R -38) (comment AE)
   (KRN O 305 R -27) (comment Aring)
   (KRN O 304 R -27) (comment Adieresis)
   (KRN O 303 R -27) (comment Atilde)
   (KRN O 302 R -27) (comment Acircumflex)
   (KRN O 301 R -27) (comment Aacute)
   (KRN O 300 R -27) (comment Agrave)
   (KRN O 23 R -78) (comment guillemotleft)
   (KRN C v R -31)
   (KRN C u R -53)
   (KRN C p R -53)
   (KRN C o R -61)
   (KRN C i R -16)
   (KRN C g R -82)
   (KRN C e R -63)
   (KRN C a R -56)
   (KRN C T R 30)
   (KRN C S R -15)
   (KRN C O R -36)
   (KRN C G R -27)
   (KRN C C R -34)
   (KRN C A R -27)
   (KRN O 73 R -29) (comment semicolon)
   (KRN O 72 R -40) (comment colon)
   (KRN O 56 R -53) (comment period)
   (KRN O 55 R -47) (comment hyphen)
   (KRN O 54 R -50) (comment comma)
   (KRN O 341 R -56) (comment aacute)
   (KRN O 342 R -56) (comment acircumflex)
   (KRN O 344 R -56) (comment adieresis)
   (KRN O 340 R -56) (comment agrave)
   (KRN O 345 R -56) (comment aring)
   (KRN O 343 R -56) (comment atilde)
   (KRN O 307 R -34) (comment Ccedilla)
   (KRN O 351 R -63) (comment eacute)
   (KRN O 352 R -63) (comment ecircumflex)
   (KRN O 353 R -63) (comment edieresis)
   (KRN O 350 R -63) (comment egrave)
   (KRN O 355 R -16) (comment iacute)
   (KRN O 356 R -16) (comment icircumflex)
   (KRN O 357 R -16) (comment idieresis)
   (KRN O 354 R -16) (comment igrave)
   (KRN O 363 R -61) (comment oacute)
   (KRN O 364 R -61) (comment ocircumflex)
   (KRN O 366 R -61) (comment odieresis)
   (KRN O 362 R -61) (comment ograve)
   (KRN O 365 R -61) (comment otilde)
   (KRN O 222 R -15) (comment Scaron)
   (KRN O 372 R -53) (comment uacute)
   (KRN O 373 R -53) (comment ucircumflex)
   (KRN O 374 R -53) (comment udieresis)
   (KRN O 371 R -53) (comment ugrave)
   (STOP)
   (LABEL O 340) (comment agrave)
   (KRN O 270 R 2) (comment ydieresis)
   (KRN O 375 R 2) (comment yacute)
   (KRN O 47 R -22) (comment quoteright)
   (KRN C j R -3)
   (KRN C w R 3)
   (KRN C y R 2)
   (STOP)
   (LABEL O 341) (comment aacute)
   (KRN O 270 R 2) (comment ydieresis)
   (KRN O 375 R 2) (comment yacute)
   (KRN O 47 R -22) (comment quoteright)
   (KRN C j R -3)
   (KRN C w R 3)
   (KRN C y R 2)
   (STOP)
   (LABEL O 342) (comment acircumflex)
   (KRN O 270 R 2) (comment ydieresis)
   (KRN O 375 R 2) (comment yacute)
   (KRN O 47 R -22) (comment quoteright)
   (KRN C y R 2)
   (KRN C w R 3)
   (KRN C j R -3)
   (STOP)
   (LABEL O 343) (comment atilde)
   (KRN O 270 R 2) (comment ydieresis)
   (KRN O 375 R 2) (comment yacute)
   (KRN O 47 R -22) (comment quoteright)
   (KRN C y R 2)
   (KRN C w R 3)
   (KRN C j R -3)
   (STOP)
   (LABEL O 344) (comment adieresis)
   (KRN O 270 R 2) (comment ydieresis)
   (KRN O 375 R 2) (comment yacute)
   (KRN O 47 R -22) (comment quoteright)
   (KRN C j R -3)
   (KRN C w R 3)
   (KRN C y R 2)
   (STOP)
   (LABEL O 345) (comment aring)
   (KRN O 270 R 2) (comment ydieresis)
   (KRN O 375 R 2) (comment yacute)
   (KRN O 47 R -22) (comment quoteright)
   (KRN C j R -3)
   (KRN C w R 3)
   (KRN C y R 2)
   (STOP)
   (LABEL O 346) (comment ae)
   (KRN O 270 R 5) (comment ydieresis)
   (KRN O 375 R 5) (comment yacute)
   (KRN C w R 3)
   (KRN C y R 5)
   (STOP)
   (LABEL O 347) (comment ccedilla)
   (KRN C k R -28)
   (KRN C h R -26)
   (STOP)
   (LABEL O 350) (comment egrave)
   (KRN O 270 R 3) (comment ydieresis)
   (KRN O 375 R 3) (comment yacute)
   (KRN O 47 R -16) (comment quoteright)
   (KRN C y R 3)
   (KRN C x R -12)
   (KRN C w R 2)
   (KRN C t R -15)
   (STOP)
   (LABEL O 351) (comment eacute)
   (KRN O 270 R 3) (comment ydieresis)
   (KRN O 375 R 3) (comment yacute)
   (KRN O 47 R -16) (comment quoteright)
   (KRN C x R -12)
   (KRN C t R -15)
   (KRN C w R 2)
   (KRN C y R 3)
   (STOP)
   (LABEL O 352) (comment ecircumflex)
   (KRN O 270 R 3) (comment ydieresis)
   (KRN O 375 R 3) (comment yacute)
   (KRN O 47 R -16) (comment quoteright)
   (KRN C x R -12)
   (KRN C t R -15)
   (KRN C w R 2)
   (KRN C y R 3)
   (STOP)
   (LABEL O 353) (comment edieresis)
   (KRN O 270 R 3) (comment ydieresis)
   (KRN O 375 R 3) (comment yacute)
   (KRN O 47 R -16) (comment quoteright)
   (KRN C y R 3)
   (KRN C x R -12)
   (KRN C w R 2)
   (KRN C t R -15)
   (STOP)
   (LABEL O 354) (comment igrave)
   (KRN C j R -23)
   (KRN C T R -11)
   (STOP)
   (LABEL O 355) (comment iacute)
   (KRN C j R -23)
   (KRN C T R -11)
   (STOP)
   (LABEL O 356) (comment icircumflex)
   (KRN C j R -23)
   (KRN C T R -11)
   (STOP)
   (LABEL O 357) (comment idieresis)
   (KRN C j R -23)
   (KRN C T R -11)
   (STOP)
   (LABEL O 361) (comment ntilde)
   (KRN O 270 R -7) (comment ydieresis)
   (KRN O 375 R -7) (comment yacute)
   (KRN O 47 R -28) (comment quoteright)
   (KRN C y R -7)
   (KRN C w R -7)
   (KRN C v R -10)
   (KRN C T R -41)
   (STOP)
   (LABEL O 362) (comment ograve)
   (KRN O 270 R -8) (comment ydieresis)
   (KRN O 375 R -8) (comment yacute)
   (KRN O 47 R -19) (comment quoteright)
   (KRN C x R -27)
   (KRN C t R -5)
   (KRN C T R -50)
   (KRN C v R -14)
   (KRN C w R -12)
   (KRN C y R -8)
   (STOP)
   (LABEL O 363) (comment oacute)
   (KRN O 270 R -8) (comment ydieresis)
   (KRN O 375 R -8) (comment yacute)
   (KRN O 47 R -19) (comment quoteright)
   (KRN C x R -27)
   (KRN C t R -5)
   (KRN C T R -50)
   (KRN C v R -14)
   (KRN C w R -12)
   (KRN C y R -8)
   (STOP)
   (LABEL O 364) (comment ocircumflex)
   (KRN O 270 R -8) (comment ydieresis)
   (KRN O 375 R -8) (comment yacute)
   (KRN O 47 R -19) (comment quoteright)
   (KRN C y R -8)
   (KRN C x R -27)
   (KRN C w R -12)
   (KRN C v R -14)
   (KRN C T R -50)
   (KRN C t R -5)
   (STOP)
   (LABEL O 365) (comment otilde)
   (KRN O 270 R -8) (comment ydieresis)
   (KRN O 375 R -8) (comment yacute)
   (KRN O 47 R -19) (comment quoteright)
   (KRN C y R -8)
   (KRN C x R -27)
   (KRN C w R -12)
   (KRN C v R -14)
   (KRN C t R -5)
   (KRN C T R -50)
   (STOP)
   (LABEL O 366) (comment odieresis)
   (KRN O 270 R -8) (comment ydieresis)
   (KRN O 375 R -8) (comment yacute)
   (KRN O 47 R -19) (comment quoteright)
   (KRN C T R -50)
   (KRN C t R -5)
   (KRN C v R -14)
   (KRN C w R -12)
   (KRN C x R -28)
   (KRN C y R -8)
   (STOP)
   (LABEL O 370) (comment oslash)
   (KRN O 270 R -8) (comment ydieresis)
   (KRN O 375 R -8) (comment yacute)
   (KRN O 47 R -19) (comment quoteright)
   (KRN C y R -8)
   (KRN C x R -27)
   (KRN C w R -12)
   (KRN C v R -14)
   (KRN C t R -5)
   (KRN C T R -50)
   (STOP)
   (LABEL O 371) (comment ugrave)
   (KRN O 47 R -21) (comment quoteright)
   (STOP)
   (LABEL O 372) (comment uacute)
   (KRN O 47 R -21) (comment quoteright)
   (STOP)
   (LABEL O 373) (comment ucircumflex)
   (KRN O 47 R -21) (comment quoteright)
   (STOP)
   (LABEL O 374) (comment udieresis)
   (KRN O 47 R -21) (comment quoteright)
   (STOP)
   (LABEL O 375) (comment yacute)
   (KRN O 370 R -5) (comment oslash)
   (KRN O 366 R -5) (comment odieresis)
   (KRN O 363 R -5) (comment oacute)
   (KRN O 362 R -5) (comment ograve)
   (KRN O 352 R -7) (comment ecircumflex)
   (KRN O 351 R -7) (comment eacute)
   (KRN O 350 R -7) (comment egrave)
   (KRN O 346 R -6) (comment ae)
   (KRN O 345 R -3) (comment aring)
   (KRN O 344 R -3) (comment adieresis)
   (KRN O 343 R -3) (comment atilde)
   (KRN O 342 R -3) (comment acircumflex)
   (KRN O 341 R -3) (comment aacute)
   (KRN O 340 R -3) (comment agrave)
   (KRN C s R -13)
   (KRN C o R -5)
   (KRN C l R -9)
   (KRN C g R -24)
   (KRN C e R -7)
   (KRN C c R -3)
   (KRN C a R -3)
   (KRN O 73 R 12) (comment semicolon)
   (KRN O 72 R 5) (comment colon)
   (KRN O 56 R -16) (comment period)
   (KRN O 55 R 14) (comment hyphen)
   (KRN O 54 R -12) (comment comma)
   (KRN O 347 R -3) (comment ccedilla)
   (KRN O 353 R -7) (comment edieresis)
   (KRN O 364 R -5) (comment ocircumflex)
   (KRN O 365 R -5) (comment otilde)
   (KRN O 262 R -13) (comment scaron)
   (STOP)
   )
(CHARACTER O 0 (comment grave)
   (CHARWD R 333)
   (CHARHT R 664)
   )
(CHARACTER O 1 (comment acute)
   (CHARWD R 333)
   (CHARHT R 664)
   (CHARIC R 70)
   )
(CHARACTER O 2 (comment circumflex)
   (CHARWD R 333)
   (CHARHT R 661)
   (CHARIC R 52)
   )
(CHARACTER O 3 (comment tilde)
   (CHARWD R 333)
   (CHARHT R 624)
   (CHARIC R 94)
   )
(CHARACTER O 4 (comment dieresis)
   (CHARWD R 333)
   (CHARHT R 606)
   (CHARIC R 72)
   )
(CHARACTER O 5 (comment hungarumlaut)
   (CHARWD R 333)
   (CHARHT R 664)
   (CHARIC R 153)
   )
(CHARACTER O 6 (comment ring)
   (CHARWD R 333)
   (CHARHT R 707)
   (CHARIC R 22)
   )
(CHARACTER O 7 (comment caron)
   (CHARWD R 333)
   (CHARHT R 661)
   (CHARIC R 93)
   )
(CHARACTER O 10 (comment breve)
   (CHARWD R 333)
   (CHARHT R 650)
   (CHARIC R 85)
   )
(CHARACTER O 11 (comment macron)
   (CHARWD R 333)
   (CHARHT R 583)
   (CHARIC R 78)
   )
(CHARACTER O 12 (comment dotaccent)
   (CHARWD R 333)
   (CHARHT R 606)
   )
(CHARACTER O 13 (comment cedilla)
   (CHARWD R 333)
   (CHARDP R 217)
   )
(CHARACTER O 14 (comment ogonek)
   (CHARWD R 333)
   (CHARHT R 40)
   (CHARDP R 169)
   )
(CHARACTER O 15 (comment quotesinglbase)
   (CHARWD R 333)
   (CHARHT R 101)
   (CHARDP R 129)
   )
(CHARACTER O 16 (comment guilsinglleft)
   (CHARWD R 333)
   (CHARHT R 403)
   )
(CHARACTER O 17 (comment guilsinglright)
   (CHARWD R 333)
   (CHARHT R 403)
   )
(CHARACTER O 20 (comment quotedblleft)
   (CHARWD R 556)
   (CHARHT R 666)
   )
(CHARACTER O 21 (comment quotedblright)
   (CHARWD R 556)
   (CHARHT R 666)
   )
(CHARACTER O 22 (comment quotedblbase)
   (CHARWD R 556)
   (CHARHT R 101)
   (CHARDP R 129)
   )
(CHARACTER O 23 (comment guillemotleft)
   (CHARWD R 500)
   (CHARHT R 403)
   )
(CHARACTER O 24 (comment guillemotright)
   (CHARWD R 500)
   (CHARHT R 403)
   )
(CHARACTER O 25 (comment endash)
   (CHARWD R 500)
   (CHARHT R 243)
   (CHARIC R 5)
   )
(CHARACTER O 26 (comment emdash)
   (CHARWD R 889)
   (CHARHT R 243)
   (CHARIC R 5)
   )
(CHARACTER O 27 (comment uni200B)
   (CHARWD R 0)
   )
(CHARACTER O 30 (comment perthousandzero)
   (CHARWD R 362)
   (CHARHT R 330)
   (CHARDP R 19)
   )
(CHARACTER O 31 (comment dotlessi)
   (CHARWD R 278)
   (CHARHT R 441)
   (CHARDP R 11)
   )
(CHARACTER O 32 (comment uni0237)
   (CHARWD R 278)
   (CHARHT R 441)
   (CHARDP R 207)
   )
(CHARACTER O 33 (comment ff)
   (CHARWD R 527)
   (CHARHT R 678)
   (CHARDP R 207)
   (CHARIC R 146)
   )
(CHARACTER O 34 (comment fi)
   (CHARWD R 500)
   (CHARHT R 681)
   (CHARDP R 207)
   )
(CHARACTER O 35 (comment fl)
   (CHARWD R 500)
   (CHARHT R 682)
   (CHARDP R 204)
   (CHARIC R 18)
   )
(CHARACTER O 36 (comment ffi)
   (CHARWD R 744)
   (CHARHT R 681)
   (CHARDP R 207)
   )
(CHARACTER O 37 (comment ffl)
   (CHARWD R 745)
   (CHARHT R 682)
   (CHARDP R 207)
   (CHARIC R 18)
   )
(CHARACTER O 40 (comment uni2423)
   (CHARWD R 500)
   (CHARHT R 16)
   (CHARDP R 120)
   )
(CHARACTER O 41 (comment exclam)
   (CHARWD R 333)
   (CHARHT R 667)
   (CHARDP R 11)
   )
(CHARACTER O 42 (comment quotedbl)
   (CHARWD R 420)
   (CHARHT R 666)
   (CHARIC R 12)
   )
(CHARACTER O 43 (comment numbersign)
   (CHARWD R 501)
   (CHARHT R 676)
   (CHARIC R 39)
   )
(CHARACTER O 44 (comment dollar)
   (CHARWD R 500)
   (CHARHT R 731)
   (CHARDP R 89)
   )
(CHARACTER O 45 (comment percent)
   (CHARWD R 755)
   (CHARHT R 706)
   (CHARDP R 19)
   )
(CHARACTER O 46 (comment ampersand)
   (CHARWD R 778)
   (CHARHT R 666)
   (CHARDP R 18)
   )
(CHARACTER O 47 (comment quoteright)
   (CHARWD R 333)
   (CHARHT R 666)
   )
(CHARACTER O 50 (comment parenleft)
   (CHARWD R 333)
   (CHARHT R 669)
   (CHARDP R 181)
   )
(CHARACTER O 51 (comment parenright)
   (CHARWD R 333)
   (CHARHT R 669)
   (CHARDP R 180)
   )
(CHARACTER O 52 (comment asterisk)
   (CHARWD R 500)
   (CHARHT R 666)
   )
(CHARACTER O 53 (comment plus)
   (CHARWD R 675)
   (CHARHT R 506)
   )
(CHARACTER O 54 (comment comma)
   (CHARWD R 250)
   (CHARHT R 101)
   (CHARDP R 129)
   )
(CHARACTER O 55 (comment hyphen)
   (CHARWD R 333)
   (CHARHT R 255)
   )
(CHARACTER O 56 (comment period)
   (CHARWD R 250)
   (CHARHT R 100)
   (CHARDP R 11)
   )
(CHARACTER O 57 (comment slash)
   (CHARWD R 278)
   (CHARHT R 666)
   (CHARDP R 18)
   (CHARIC R 108)
   )
(CHARACTER C 0
   (CHARWD R 500)
   (CHARHT R 676)
   (CHARDP R 7)
   )
(CHARACTER C 1
   (CHARWD R 500)
   (CHARHT R 676)
   )
(CHARACTER C 2
   (CHARWD R 500)
   (CHARHT R 676)
   )
(CHARACTER C 3
   (CHARWD R 500)
   (CHARHT R 676)
   (CHARDP R 7)
   )
(CHARACTER C 4
   (CHARWD R 500)
   (CHARHT R 676)
   )
(CHARACTER C 5
   (CHARWD R 500)
   (CHARHT R 666)
   (CHARDP R 7)
   )
(CHARACTER C 6
   (CHARWD R 500)
   (CHARHT R 686)
   (CHARDP R 7)
   (CHARIC R 21)
   )
(CHARACTER C 7
   (CHARWD R 500)
   (CHARHT R 666)
   (CHARDP R 8)
   (CHARIC R 37)
   )
(CHARACTER C 8
   (CHARWD R 500)
   (CHARHT R 676)
   (CHARDP R 7)
   )
(CHARACTER C 9
   (CHARWD R 500)
   (CHARHT R 676)
   (CHARDP R 17)
   )
(CHARACTER O 72 (comment colon)
   (CHARWD R 333)
   (CHARHT R 441)
   (CHARDP R 11)
   )
(CHARACTER O 73 (comment semicolon)
   (CHARWD R 333)
   (CHARHT R 441)
   (CHARDP R 129)
   )
(CHARACTER O 74 (comment less)
   (CHARWD R 675)
   (CHARHT R 516)
   (CHARDP R 10)
   )
(CHARACTER O 75 (comment equal)
   (CHARWD R 675)
   (CHARHT R 386)
   )
(CHARACTER O 76 (comment greater)
   (CHARWD R 675)
   (CHARHT R 516)
   (CHARDP R 10)
   )
(CHARACTER O 77 (comment question)
   (CHARWD R 500)
   (CHARHT R 664)
   (CHARDP R 12)
   )
(CHARACTER O 100 (comment at)
   (CHARWD R 920)
   (CHARHT R 666)
   (CHARDP R 18)
   )
(CHARACTER C A
   (CHARWD R 611)
   (CHARHT R 668)
   )
(CHARACTER C B
   (CHARWD R 611)
   (CHARHT R 653)
   )
(CHARACTER C C
   (CHARWD R 667)
   (CHARHT R 666)
   (CHARDP R 18)
   (CHARIC R 22)
   )
(CHARACTER C D
   (CHARWD R 722)
   (CHARHT R 653)
   )
(CHARACTER C E
   (CHARWD R 611)
   (CHARHT R 653)
   (CHARIC R 23)
   )
(CHARACTER C F
   (CHARWD R 611)
   (CHARHT R 653)
   (CHARIC R 34)
   )
(CHARACTER C G
   (CHARWD R 722)
   (CHARHT R 666)
   (CHARDP R 18)
   )
(CHARACTER C H
   (CHARWD R 722)
   (CHARHT R 653)
   (CHARIC R 47)
   )
(CHARACTER C I
   (CHARWD R 333)
   (CHARHT R 653)
   (CHARIC R 51)
   )
(CHARACTER C J
   (CHARWD R 444)
   (CHARHT R 653)
   (CHARDP R 18)
   (CHARIC R 47)
   )
(CHARACTER C K
   (CHARWD R 667)
   (CHARHT R 653)
   (CHARIC R 55)
   )
(CHARACTER C L
   (CHARWD R 556)
   (CHARHT R 653)
   (CHARIC R 3)
   )
(CHARACTER C M
   (CHARWD R 833)
   (CHARHT R 653)
   (CHARIC R 39)
   )
(CHARACTER C N
   (CHARWD R 667)
   (CHARHT R 653)
   (CHARDP R 15)
   (CHARIC R 60)
   )
(CHARACTER C O
   (CHARWD R 722)
   (CHARHT R 667)
   (CHARDP R 18)
   )
(CHARACTER C P
   (CHARWD R 611)
   (CHARHT R 653)
   )
(CHARACTER C Q
   (CHARWD R 722)
   (CHARHT R 666)
   (CHARDP R 182)
   )
(CHARACTER C R
   (CHARWD R 611)
   (CHARHT R 653)
   )
(CHARACTER C S
   (CHARWD R 500)
   (CHARHT R 667)
   (CHARDP R 18)
   (CHARIC R 8)
   )
(CHARACTER C T
   (CHARWD R 556)
   (CHARHT R 653)
   (CHARIC R 77)
   )
(CHARACTER C U
   (CHARWD R 722)
   (CHARHT R 653)
   (CHARDP R 18)
   (CHARIC R 43)
   )
(CHARACTER C V
   (CHARWD R 611)
   (CHARHT R 653)
   (CHARDP R 18)
   (CHARIC R 77)
   )
(CHARACTER C W
   (CHARWD R 833)
   (CHARHT R 653)
   (CHARDP R 18)
   (CHARIC R 73)
   )
(CHARACTER C X
   (CHARWD R 611)
   (CHARHT R 653)
   (CHARIC R 44)
   )
(CHARACTER C Y
   (CHARWD R 556)
   (CHARHT R 653)
   (CHARIC R 77)
   )
(CHARACTER C Z
   (CHARWD R 556)
   (CHARHT R 653)
   (CHARIC R 50)
   )
(CHARACTER O 133 (comment bracketleft)
   (CHARWD R 389)
   (CHARHT R 663)
   (CHARDP R 153)
   (CHARIC R 2)
   )
(CHARACTER O 134 (comment backslash)
   (CHARWD R 278)
   (CHARHT R 666)
   (CHARDP R 18)
   (CHARIC R 41)
   )
(CHARACTER O 135 (comment bracketright)
   (CHARWD R 389)
   (CHARHT R 663)
   (CHARDP R 153)
   )
(CHARACTER O 136 (comment asciicircum)
   (CHARWD R 422)
   (CHARHT R 666)
   )
(CHARACTER O 137 (comment underscore)
   (CHARWD R 500)
   (CHARDP R 125)
   )
(CHARACTER O 140 (comment quoteleft)
   (CHARWD R 333)
   (CHARHT R 666)
   )
(CHARACTER C a
   (CHARWD R 501)
   (CHARHT R 441)
   (CHARDP R 11)
   )
(CHARACTER C b
   (CHARWD R 500)
   (CHARHT R 683)
   (CHARDP R 11)
   )
(CHARACTER C c
   (CHARWD R 444)
   (CHARHT R 441)
   (CHARDP R 11)
   )
(CHARACTER C d
   (CHARWD R 500)
   (CHARHT R 683)
   (CHARDP R 13)
   (CHARIC R 27)
   )
(CHARACTER C e
   (CHARWD R 444)
   (CHARHT R 441)
   (CHARDP R 11)
   )
(CHARACTER C f
   (CHARWD R 278)
   (CHARHT R 678)
   (CHARDP R 207)
   (CHARIC R 146)
   )
(CHARACTER C g
   (CHARWD R 500)
   (CHARHT R 441)
   (CHARDP R 206)
   )
(CHARACTER C h
   (CHARWD R 500)
   (CHARHT R 683)
   (CHARDP R 9)
   )
(CHARACTER C i
   (CHARWD R 278)
   (CHARHT R 654)
   (CHARDP R 11)
   )
(CHARACTER C j
   (CHARWD R 278)
   (CHARHT R 652)
   (CHARDP R 207)
   (CHARIC R 1)
   )
(CHARACTER C k
   (CHARWD R 444)
   (CHARHT R 683)
   (CHARDP R 11)
   (CHARIC R 17)
   )
(CHARACTER C l
   (CHARWD R 278)
   (CHARHT R 683)
   (CHARDP R 11)
   (CHARIC R 1)
   )
(CHARACTER C m
   (CHARWD R 722)
   (CHARHT R 441)
   (CHARDP R 9)
   )
(CHARACTER C n
   (CHARWD R 500)
   (CHARHT R 441)
   (CHARDP R 9)
   )
(CHARACTER C o
   (CHARWD R 500)
   (CHARHT R 441)
   (CHARDP R 11)
   )
(CHARACTER C p
   (CHARWD R 504)
   (CHARHT R 441)
   (CHARDP R 205)
   )
(CHARACTER C q
   (CHARWD R 500)
   (CHARHT R 441)
   (CHARDP R 209)
   )
(CHARACTER C r
   (CHARWD R 389)
   (CHARHT R 441)
   (CHARIC R 23)
   )
(CHARACTER C s
   (CHARWD R 389)
   (CHARHT R 442)
   (CHARDP R 13)
   )
(CHARACTER C t
   (CHARWD R 278)
   (CHARHT R 546)
   (CHARDP R 11)
   (CHARIC R 18)
   )
(CHARACTER C u
   (CHARWD R 500)
   (CHARHT R 441)
   (CHARDP R 11)
   )
(CHARACTER C v
   (CHARWD R 444)
   (CHARHT R 441)
   (CHARDP R 18)
   )
(CHARACTER C w
   (CHARWD R 667)
   (CHARHT R 441)
   (CHARDP R 18)
   )
(CHARACTER C x
   (CHARWD R 444)
   (CHARHT R 441)
   (CHARDP R 11)
   (CHARIC R 3)
   )
(CHARACTER C y
   (CHARWD R 444)
   (CHARHT R 441)
   (CHARDP R 206)
   )
(CHARACTER C z
   (CHARWD R 389)
   (CHARHT R 428)
   (CHARDP R 81)
   )
(CHARACTER O 173 (comment braceleft)
   (CHARWD R 400)
   (CHARHT R 687)
   (CHARDP R 177)
   (CHARIC R 7)
   )
(CHARACTER O 174 (comment bar)
   (CHARWD R 275)
   (CHARHT R 666)
   (CHARDP R 18)
   )
(CHARACTER O 175 (comment braceright)
   (CHARWD R 400)
   (CHARHT R 687)
   (CHARDP R 177)
   )
(CHARACTER O 176 (comment asciitilde)
   (CHARWD R 541)
   (CHARHT R 323)
   )
(CHARACTER O 177 (comment uni2010)
   (CHARWD R 333)
   (CHARHT R 257)
   )
(CHARACTER O 200 (comment uni0102)
   (CHARWD R 611)
   (CHARHT R 862)
   )
(CHARACTER O 201 (comment uni0104)
   (CHARWD R 611)
   (CHARHT R 668)
   (CHARDP R 169)
   (CHARIC R 15)
   )
(CHARACTER O 202 (comment uni0106)
   (CHARWD R 667)
   (CHARHT R 876)
   (CHARDP R 18)
   (CHARIC R 22)
   )
(CHARACTER O 203 (comment uni010C)
   (CHARWD R 667)
   (CHARHT R 875)
   (CHARDP R 18)
   (CHARIC R 22)
   )
(CHARACTER O 204 (comment uni010E)
   (CHARWD R 722)
   (CHARHT R 875)
   )
(CHARACTER O 205 (comment uni011A)
   (CHARWD R 611)
   (CHARHT R 875)
   (CHARIC R 23)
   )
(CHARACTER O 206 (comment uni0118)
   (CHARWD R 611)
   (CHARHT R 653)
   (CHARDP R 175)
   (CHARIC R 23)
   )
(CHARACTER O 207 (comment uni011E)
   (CHARWD R 722)
   (CHARHT R 866)
   (CHARDP R 18)
   )
(CHARACTER O 210 (comment uni0139)
   (CHARWD R 556)
   (CHARHT R 876)
   (CHARIC R 3)
   )
(CHARACTER O 211 (comment uni013D)
   (CHARWD R 556)
   (CHARHT R 666)
   (CHARIC R 39)
   )
(CHARACTER O 212 (comment Lslash)
   (CHARWD R 556)
   (CHARHT R 653)
   (CHARIC R 3)
   )
(CHARACTER O 213 (comment uni0143)
   (CHARWD R 667)
   (CHARHT R 876)
   (CHARDP R 15)
   (CHARIC R 60)
   )
(CHARACTER O 214 (comment uni0147)
   (CHARWD R 667)
   (CHARHT R 875)
   (CHARDP R 15)
   (CHARIC R 60)
   )
(CHARACTER O 215 (comment uni014A)
   (CHARWD R 722)
   (CHARHT R 666)
   (CHARDP R 18)
   )
(CHARACTER O 216 (comment uni0150)
   (CHARWD R 722)
   (CHARHT R 876)
   (CHARDP R 18)
   )
(CHARACTER O 217 (comment uni0154)
   (CHARWD R 611)
   (CHARHT R 876)
   )
(CHARACTER O 220 (comment uni0158)
   (CHARWD R 611)
   (CHARHT R 875)
   )
(CHARACTER O 221 (comment uni015A)
   (CHARWD R 500)
   (CHARHT R 876)
   (CHARDP R 18)
   (CHARIC R 8)
   )
(CHARACTER O 222 (comment Scaron)
   (CHARWD R 500)
   (CHARHT R 875)
   (CHARDP R 18)
   (CHARIC R 32)
   )
(CHARACTER O 223 (comment uni015E)
   (CHARWD R 500)
   (CHARHT R 667)
   (CHARDP R 217)
   (CHARIC R 8)
   )
(CHARACTER O 224 (comment uni0164)
   (CHARWD R 556)
   (CHARHT R 875)
   (CHARIC R 77)
   )
(CHARACTER O 225 (comment uni0162)
   (CHARWD R 556)
   (CHARHT R 653)
   (CHARDP R 217)
   (CHARIC R 77)
   )
(CHARACTER O 226 (comment uni0170)
   (CHARWD R 722)
   (CHARHT R 876)
   (CHARDP R 18)
   (CHARIC R 43)
   )
(CHARACTER O 227 (comment uni016E)
   (CHARWD R 722)
   (CHARHT R 907)
   (CHARDP R 18)
   (CHARIC R 43)
   )
(CHARACTER O 230 (comment Ydieresis)
   (CHARWD R 556)
   (CHARHT R 818)
   (CHARIC R 77)
   )
(CHARACTER O 231 (comment uni0179)
   (CHARWD R 556)
   (CHARHT R 876)
   (CHARIC R 50)
   )
(CHARACTER O 232 (comment Zcaron)
   (CHARWD R 556)
   (CHARHT R 875)
   (CHARIC R 50)
   )
(CHARACTER O 233 (comment uni017B)
   (CHARWD R 556)
   (CHARHT R 818)
   (CHARIC R 50)
   )
(CHARACTER O 234 (comment uni0132)
   (CHARWD R 750)
   (CHARHT R 653)
   (CHARDP R 18)
   (CHARIC R 33)
   )
(CHARACTER O 235 (comment uni0130)
   (CHARWD R 333)
   (CHARHT R 818)
   (CHARIC R 51)
   )
(CHARACTER O 236 (comment uni0111)
   (CHARWD R 500)
   (CHARHT R 683)
   (CHARDP R 13)
   (CHARIC R 80)
   )
(CHARACTER O 237 (comment section)
   (CHARWD R 500)
   (CHARHT R 666)
   (CHARDP R 162)
   )
(CHARACTER O 240 (comment uni0103)
   (CHARWD R 501)
   (CHARHT R 650)
   (CHARDP R 11)
   )
(CHARACTER O 241 (comment uni0105)
   (CHARWD R 501)
   (CHARHT R 441)
   (CHARDP R 169)
   (CHARIC R 28)
   )
(CHARACTER O 242 (comment uni0107)
   (CHARWD R 444)
   (CHARHT R 664)
   (CHARDP R 11)
   )
(CHARACTER O 243 (comment uni010D)
   (CHARWD R 444)
   (CHARHT R 661)
   (CHARDP R 11)
   (CHARIC R 29)
   )
(CHARACTER O 244 (comment uni010F)
   (CHARWD R 609)
   (CHARHT R 691)
   (CHARDP R 13)
   (CHARIC R 88)
   )
(CHARACTER O 245 (comment uni011B)
   (CHARWD R 444)
   (CHARHT R 661)
   (CHARDP R 11)
   (CHARIC R 58)
   )
(CHARACTER O 246 (comment uni0119)
   (CHARWD R 444)
   (CHARHT R 441)
   (CHARDP R 175)
   )
(CHARACTER O 247 (comment uni011F)
   (CHARWD R 500)
   (CHARHT R 650)
   (CHARDP R 206)
   )
(CHARACTER O 250 (comment uni013A)
   (CHARWD R 278)
   (CHARHT R 876)
   (CHARDP R 11)
   (CHARIC R 70)
   )
(CHARACTER O 251 (comment uni013E)
   (CHARWD R 278)
   (CHARHT R 693)
   (CHARDP R 11)
   (CHARIC R 170)
   )
(CHARACTER O 252 (comment lslash)
   (CHARWD R 278)
   (CHARHT R 683)
   (CHARDP R 11)
   (CHARIC R 29)
   )
(CHARACTER O 253 (comment uni0144)
   (CHARWD R 500)
   (CHARHT R 664)
   (CHARDP R 9)
   )
(CHARACTER O 254 (comment uni0148)
   (CHARWD R 500)
   (CHARHT R 661)
   (CHARDP R 9)
   )
(CHARACTER O 255 (comment uni014B)
   (CHARWD R 500)
   (CHARHT R 441)
   (CHARDP R 208)
   )
(CHARACTER O 256 (comment uni0151)
   (CHARWD R 500)
   (CHARHT R 664)
   (CHARDP R 11)
   (CHARIC R 41)
   )
(CHARACTER O 257 (comment uni0155)
   (CHARWD R 389)
   (CHARHT R 664)
   (CHARIC R 23)
   )
(CHARACTER O 260 (comment uni0159)
   (CHARWD R 389)
   (CHARHT R 663)
   (CHARIC R 37)
   )
(CHARACTER O 261 (comment uni015B)
   (CHARWD R 389)
   (CHARHT R 664)
   (CHARDP R 13)
   (CHARIC R 14)
   )
(CHARACTER O 262 (comment scaron)
   (CHARWD R 389)
   (CHARHT R 663)
   (CHARDP R 13)
   (CHARIC R 37)
   )
(CHARACTER O 263 (comment uni015F)
   (CHARWD R 389)
   (CHARHT R 442)
   (CHARDP R 217)
   )
(CHARACTER O 264 (comment uni0165)
   (CHARWD R 278)
   (CHARHT R 693)
   (CHARDP R 11)
   (CHARIC R 175)
   )
(CHARACTER O 265 (comment uni0163)
   (CHARWD R 278)
   (CHARHT R 546)
   (CHARDP R 217)
   (CHARIC R 18)
   )
(CHARACTER O 266 (comment uni0171)
   (CHARWD R 500)
   (CHARHT R 664)
   (CHARDP R 11)
   (CHARIC R 11)
   )
(CHARACTER O 267 (comment uni016F)
   (CHARWD R 500)
   (CHARHT R 691)
   (CHARDP R 11)
   )
(CHARACTER O 270 (comment ydieresis)
   (CHARWD R 444)
   (CHARHT R 606)
   (CHARDP R 206)
   )
(CHARACTER O 271 (comment uni017A)
   (CHARWD R 389)
   (CHARHT R 664)
   (CHARDP R 81)
   (CHARIC R 1)
   )
(CHARACTER O 272 (comment zcaron)
   (CHARWD R 389)
   (CHARHT R 663)
   (CHARDP R 81)
   (CHARIC R 37)
   )
(CHARACTER O 273 (comment uni017C)
   (CHARWD R 389)
   (CHARHT R 606)
   (CHARDP R 81)
   )
(CHARACTER O 274 (comment uni0133)
   (CHARWD R 500)
   (CHARHT R 654)
   (CHARDP R 207)
   )
(CHARACTER O 275 (comment exclamdown)
   (CHARWD R 389)
   (CHARHT R 474)
   (CHARDP R 205)
   )
(CHARACTER O 276 (comment questiondown)
   (CHARWD R 500)
   (CHARHT R 473)
   (CHARDP R 205)
   )
(CHARACTER O 277 (comment sterling)
   (CHARWD R 500)
   (CHARHT R 670)
   (CHARDP R 8)
   (CHARIC R 17)
   )
(CHARACTER O 300 (comment Agrave)
   (CHARWD R 611)
   (CHARHT R 914)
   )
(CHARACTER O 301 (comment Aacute)
   (CHARWD R 611)
   (CHARHT R 914)
   )
(CHARACTER O 302 (comment Acircumflex)
   (CHARWD R 611)
   (CHARHT R 911)
   )
(CHARACTER O 303 (comment Atilde)
   (CHARWD R 611)
   (CHARHT R 874)
   )
(CHARACTER O 304 (comment Adieresis)
   (CHARWD R 611)
   (CHARHT R 856)
   )
(CHARACTER O 305 (comment Aring)
   (CHARWD R 611)
   (CHARHT R 957)
   )
(CHARACTER O 306 (comment AE)
   (CHARWD R 889)
   (CHARHT R 653)
   (CHARIC R 22)
   )
(CHARACTER O 307 (comment Ccedilla)
   (CHARWD R 667)
   (CHARHT R 666)
   (CHARDP R 217)
   (CHARIC R 22)
   )
(CHARACTER O 310 (comment Egrave)
   (CHARWD R 611)
   (CHARHT R 914)
   (CHARIC R 23)
   )
(CHARACTER O 311 (comment Eacute)
   (CHARWD R 611)
   (CHARHT R 914)
   (CHARIC R 23)
   )
(CHARACTER O 312 (comment Ecircumflex)
   (CHARWD R 611)
   (CHARHT R 911)
   (CHARIC R 23)
   )
(CHARACTER O 313 (comment Edieresis)
   (CHARWD R 611)
   (CHARHT R 856)
   (CHARIC R 23)
   )
(CHARACTER O 314 (comment Igrave)
   (CHARWD R 333)
   (CHARHT R 914)
   (CHARIC R 65)
   )
(CHARACTER O 315 (comment Iacute)
   (CHARWD R 333)
   (CHARHT R 914)
   (CHARIC R 81)
   )
(CHARACTER O 316 (comment Icircumflex)
   (CHARWD R 333)
   (CHARHT R 911)
   (CHARIC R 117)
   )
(CHARACTER O 317 (comment Idieresis)
   (CHARWD R 333)
   (CHARHT R 856)
   (CHARIC R 124)
   )
(CHARACTER O 320 (comment Eth)
   (CHARWD R 722)
   (CHARHT R 653)
   )
(CHARACTER O 321 (comment Ntilde)
   (CHARWD R 667)
   (CHARHT R 874)
   (CHARDP R 15)
   (CHARIC R 60)
   )
(CHARACTER O 322 (comment Ograve)
   (CHARWD R 722)
   (CHARHT R 914)
   (CHARDP R 18)
   )
(CHARACTER O 323 (comment Oacute)
   (CHARWD R 722)
   (CHARHT R 914)
   (CHARDP R 18)
   )
(CHARACTER O 324 (comment Ocircumflex)
   (CHARWD R 722)
   (CHARHT R 911)
   (CHARDP R 18)
   )
(CHARACTER O 325 (comment Otilde)
   (CHARWD R 722)
   (CHARHT R 874)
   (CHARDP R 18)
   )
(CHARACTER O 326 (comment Odieresis)
   (CHARWD R 722)
   (CHARHT R 856)
   (CHARDP R 18)
   )
(CHARACTER O 327 (comment OE)
   (CHARWD R 944)
   (CHARHT R 666)
   (CHARDP R 8)
   (CHARIC R 20)
   )
(CHARACTER O 330 (comment Oslash)
   (CHARWD R 722)
   (CHARHT R 722)
   (CHARDP R 105)
   )
(CHARACTER O 331 (comment Ugrave)
   (CHARWD R 722)
   (CHARHT R 914)
   (CHARDP R 18)
   (CHARIC R 43)
   )
(CHARACTER O 332 (comment Uacute)
   (CHARWD R 722)
   (CHARHT R 914)
   (CHARDP R 18)
   (CHARIC R 43)
   )
(CHARACTER O 333 (comment Ucircumflex)
   (CHARWD R 722)
   (CHARHT R 911)
   (CHARDP R 18)
   (CHARIC R 43)
   )
(CHARACTER O 334 (comment Udieresis)
   (CHARWD R 722)
   (CHARHT R 856)
   (CHARDP R 18)
   (CHARIC R 43)
   )
(CHARACTER O 335 (comment Yacute)
   (CHARWD R 556)
   (CHARHT R 914)
   (CHARIC R 77)
   )
(CHARACTER O 336 (comment Thorn)
   (CHARWD R 611)
   (CHARHT R 653)
   )
(CHARACTER O 337 (comment uni1E9E)
   (CHARWD R 1000)
   (CHARHT R 667)
   (CHARDP R 18)
   (CHARIC R 8)
   )
(CHARACTER O 340 (comment agrave)
   (CHARWD R 501)
   (CHARHT R 664)
   (CHARDP R 11)
   )
(CHARACTER O 341 (comment aacute)
   (CHARWD R 501)
   (CHARHT R 664)
   (CHARDP R 11)
   )
(CHARACTER O 342 (comment acircumflex)
   (CHARWD R 501)
   (CHARHT R 661)
   (CHARDP R 11)
   )
(CHARACTER O 343 (comment atilde)
   (CHARWD R 501)
   (CHARHT R 624)
   (CHARDP R 11)
   (CHARIC R 20)
   )
(CHARACTER O 344 (comment adieresis)
   (CHARWD R 501)
   (CHARHT R 606)
   (CHARDP R 11)
   (CHARIC R 2)
   )
(CHARACTER O 345 (comment aring)
   (CHARWD R 501)
   (CHARHT R 709)
   (CHARDP R 11)
   )
(CHARACTER O 346 (comment ae)
   (CHARWD R 667)
   (CHARHT R 441)
   (CHARDP R 11)
   )
(CHARACTER O 347 (comment ccedilla)
   (CHARWD R 444)
   (CHARHT R 441)
   (CHARDP R 217)
   )
(CHARACTER O 350 (comment egrave)
   (CHARWD R 444)
   (CHARHT R 664)
   (CHARDP R 11)
   )
(CHARACTER O 351 (comment eacute)
   (CHARWD R 444)
   (CHARHT R 664)
   (CHARDP R 11)
   )
(CHARACTER O 352 (comment ecircumflex)
   (CHARWD R 444)
   (CHARHT R 661)
   (CHARDP R 11)
   (CHARIC R 22)
   )
(CHARACTER O 353 (comment edieresis)
   (CHARWD R 444)
   (CHARHT R 606)
   (CHARDP R 11)
   (CHARIC R 31)
   )
(CHARACTER O 354 (comment igrave)
   (CHARWD R 278)
   (CHARHT R 664)
   (CHARDP R 11)
   (CHARIC R 24)
   )
(CHARACTER O 355 (comment iacute)
   (CHARWD R 278)
   (CHARHT R 664)
   (CHARDP R 11)
   (CHARIC R 40)
   )
(CHARACTER O 356 (comment icircumflex)
   (CHARWD R 278)
   (CHARHT R 661)
   (CHARDP R 11)
   (CHARIC R 73)
   )
(CHARACTER O 357 (comment idieresis)
   (CHARWD R 278)
   (CHARHT R 606)
   (CHARDP R 11)
   (CHARIC R 83)
   )
(CHARACTER O 360 (comment eth)
   (CHARWD R 500)
   (CHARHT R 683)
   (CHARDP R 11)
   )
(CHARACTER O 361 (comment ntilde)
   (CHARWD R 500)
   (CHARHT R 624)
   (CHARDP R 9)
   )
(CHARACTER O 362 (comment ograve)
   (CHARWD R 500)
   (CHARHT R 664)
   (CHARDP R 11)
   )
(CHARACTER O 363 (comment oacute)
   (CHARWD R 500)
   (CHARHT R 664)
   (CHARDP R 11)
   )
(CHARACTER O 364 (comment ocircumflex)
   (CHARWD R 500)
   (CHARHT R 661)
   (CHARDP R 11)
   )
(CHARACTER O 365 (comment otilde)
   (CHARWD R 500)
   (CHARHT R 624)
   (CHARDP R 11)
   )
(CHARACTER O 366 (comment odieresis)
   (CHARWD R 500)
   (CHARHT R 606)
   (CHARDP R 11)
   )
(CHARACTER O 367 (comment oe)
   (CHARWD R 667)
   (CHARHT R 441)
   (CHARDP R 12)
   )
(CHARACTER O 370 (comment oslash)
   (CHARWD R 500)
   (CHARHT R 554)
   (CHARDP R 135)
   )
(CHARACTER O 371 (comment ugrave)
   (CHARWD R 500)
   (CHARHT R 664)
   (CHARDP R 11)
   )
(CHARACTER O 372 (comment uacute)
   (CHARWD R 500)
   (CHARHT R 664)
   (CHARDP R 11)
   )
(CHARACTER O 373 (comment ucircumflex)
   (CHARWD R 500)
   (CHARHT R 661)
   (CHARDP R 11)
   )
(CHARACTER O 374 (comment udieresis)
   (CHARWD R 500)
   (CHARHT R 606)
   (CHARDP R 11)
   )
(CHARACTER O 375 (comment yacute)
   (CHARWD R 444)
   (CHARHT R 664)
   (CHARDP R 206)
   )
(CHARACTER O 376 (comment thorn)
   (CHARWD R 500)
   (CHARHT R 683)
   (CHARDP R 205)
   )
(CHARACTER O 377 (comment germandbls)
   (CHARWD R 500)
   (CHARHT R 679)
   (CHARDP R 207)
   )
